@@ -46,6 +46,39 @@ struct atom10ParserState {
 };
 typedef void 	(*atom10ElementParserFunc)	(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state);
 
+gchar* atom10_mark_up_text_content(gchar* content) {
+	gchar **tokens;
+	gchar **token;
+	gchar *str, *old_str;
+
+	if(!content) return NULL;
+	if(!*content) return g_strdup(content);
+
+	tokens = g_strsplit(content, "\n\n", 0);
+	
+	if (tokens[0] == NULL) { /* No tokens */
+		str = g_strdup("");
+	} else if (tokens[1] == NULL) { /* One token */
+		str = g_markup_escape_text(tokens[0], -1);
+	} else { /* Many tokens */
+		token = tokens;
+		while (*token != NULL) {
+			old_str = *token;
+			str = g_strchug(g_strchomp(*token)); /* WARNING: modifies the token string*/
+			if(str[0] != '\0') {
+				*token = g_markup_printf_escaped("<p>%s</p>", str);
+				g_free(old_str);
+			} else {
+				**token = '\0'; /* Erase the particular token because it is blank */
+			}
+			token++;
+		}
+		str = g_strjoinv("\n", tokens);
+	}
+	g_strfreev(tokens);
+
+	return str;
+}
 
 /**
  * This parses an Atom content construct.
@@ -89,7 +122,8 @@ static gchar* atom10_parse_content_construct(xmlNodePtr cur) {
 			escapeAsText = FALSE;
 			includeChildTags = FALSE;
 			baseURL = xmlNodeGetBase(cur->doc, cur);
-		} else if (NULL == type || !strcmp(type, "text") || !strncasecmp(type, "text/",5)) { /* Assume that "text/*" files can be directly displayed.. kinda stated in the RFC */
+		} else if (NULL == type || !strcmp(type, "text") || !strncasecmp(type, "text/",5)) {
+			/* Assume that "text/ *" files can be directly displayed.. kinda stated in the RFC */
 			escapeAsText = TRUE;
 			includeChildTags = FALSE;
 		} else if (!strcmp(type,"xhtml") || !strcasecmp(type, "application/xhtml+xml")) {
@@ -107,6 +141,11 @@ static gchar* atom10_parse_content_construct(xmlNodePtr cur) {
 				return g_strdup(_("This item's contents is invalid."));
 			}
 			baseURL = xmlNodeGetBase(cur->doc, cur);
+		} else {
+			/* Unknown type... lets bail? */
+			g_free(type);
+			return g_strdup(_("This item's contents is invalid."));
+			
 		}
 			
 		if (includeChildTags)
@@ -115,7 +154,14 @@ static gchar* atom10_parse_content_construct(xmlNodePtr cur) {
 			ret = utf8_fix(xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1));
 		
 		if (escapeAsText) {
-			gchar *tmp = g_markup_printf_escaped("<pre>%s</pre>", ret);
+			gchar *tmp;
+
+			g_strchug(g_strchomp(ret));
+
+			if (type != NULL && !strcasecmp(type, "text/plain"))
+				tmp = atom10_mark_up_text_content(ret);
+			else
+				tmp = g_markup_printf_escaped("<pre>%s</pre>", ret);
 			g_free(ret);
 			ret = tmp;
 		}
@@ -149,16 +195,17 @@ static gchar* atom10_parse_text_construct(xmlNodePtr cur, gboolean htmlified) {
 	/* This that need to be de-encoded and should not contain sub-tags.*/
 	if (NULL == type || !strcmp(type, "text")) {
 		ret = utf8_fix(xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1));
+		g_strchug(g_strchomp(ret));
 		
 		if (htmlified) {
-			tmp = ret;
-			ret = g_markup_printf_escaped("<pre>%s</pre>", tmp);
-			g_free(tmp);
+			tmp = atom10_mark_up_text_content(ret);
+			g_free(ret);
+			ret = tmp;
 		}
 	} else if (!strcmp(type, "html")) {
-		ret = unxmlize(utf8_fix(xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1)));
+		ret = utf8_fix(xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1));
 		if (!htmlified)
-			ret = unhtmlize(ret);
+			ret = unhtmlize(unxmlize(ret));
 	} else if(!strcmp(type, "xhtml")) {
 		/* The spec says to only show the contents of the div tag that MUST be present */
 		
@@ -194,7 +241,7 @@ static gchar * atom10_parse_person_construct(xmlNodePtr cur) {
 	g_assert(NULL != cur);
 	cur = cur->xmlChildrenNode;
 	while (cur != NULL) {
-		if(NULL == cur->name || cur->type != XML_ELEMENT_NODE || cur->ns == NULL) {
+		if(NULL == cur->name || cur->type != XML_ELEMENT_NODE || cur->ns == NULL || cur->ns->href == NULL) {
 			cur = cur->next;
 			continue;
 		}
@@ -238,7 +285,44 @@ static gchar * atom10_parse_person_construct(xmlNodePtr cur) {
 	return tmp;
 }
 
-static void atom10_parse_entry_author(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static gchar* atom10_parse_link(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
+	gchar *href, *alternate = NULL;
+
+	if(NULL != (href = utf8_fix(xmlGetNsProp(cur, BAD_CAST"href", NULL)))) {
+		xmlChar *baseURL = xmlNodeGetBase(cur->doc, cur);
+		gchar *url, *relation, *escTitle = NULL, *title;
+
+		if (baseURL == NULL && fp->htmlUrl != NULL && fp->htmlUrl[0] != '|' &&
+			strstr(fp->htmlUrl, "://") != NULL)
+			baseURL = xmlStrdup(BAD_CAST(fp->htmlUrl));
+		url = common_build_url(href, baseURL);
+
+		relation = utf8_fix(xmlGetNsProp(cur, BAD_CAST"rel", NULL));
+		title = utf8_fix(xmlGetNsProp(cur, BAD_CAST"title", NULL));
+		if (title != NULL)
+			escTitle = g_markup_escape_text(title, -1);
+		/* FIXME: Display the human readable title from the property "title" */
+		/* This current code was copied from the RSS parser.*/
+
+		if(!xmlHasNsProp(cur, BAD_CAST"rel", NULL) || relation == NULL || g_str_equal(relation, BAD_CAST"alternate"))
+			alternate = g_strdup(url);
+		else if (g_str_equal(relation, "enclosure"))
+			ip->metadata = metadata_list_append(ip->metadata, "enclosure", url);
+		else
+			/* FIXME: Maybe do something with other links such as "related" and add metadata for "via"? */;
+		xmlFree(title);
+		xmlFree(baseURL);
+		g_free(escTitle);
+		g_free(url);
+		g_free(relation);
+		g_free(href);
+	} else
+		/* FIXME: @href is required, this document is not valid Atom */;
+
+	return alternate;
+}
+
+static void atom10_parse_entry_author(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	gchar *author;
 	
 	author = atom10_parse_person_construct(cur);
@@ -246,7 +330,7 @@ static void atom10_parse_entry_author(xmlNodePtr cur, feedPtr fp, itemPtr ip, st
 	g_free(author);
 }
 
-static void atom10_parse_entry_category(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_entry_category(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	gchar *category = NULL, *categoryEsc;
 	if (xmlHasNsProp(cur, BAD_CAST"label", NULL)) {
 		category = utf8_fix(xmlGetNsProp(cur, BAD_CAST"label", NULL));
@@ -261,63 +345,35 @@ static void atom10_parse_entry_category(xmlNodePtr cur, feedPtr fp, itemPtr ip,
 	}
 }
 
-static void atom10_parse_entry_content(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_entry_content(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	gchar *content = atom10_parse_content_construct(cur);
 	if (content != NULL)
 		item_set_description(ip, content);
 	g_free(content);
 }
 
-static void atom10_parse_entry_contributor(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_entry_contributor(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	gchar *contributor = atom10_parse_person_construct(cur);
 	ip->metadata = metadata_list_append(ip->metadata, "contributor", contributor);
 	g_free(contributor);
 }
 
-static void atom10_parse_entry_id(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_entry_id(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	gchar *id = utf8_fix(xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1));
 			if (id != NULL)
 				item_set_id(ip, id);
 			g_free(id);
 }
 
-static void atom10_parse_entry_link(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
-	gchar *href;
-
-	if(NULL != (href = utf8_fix(xmlGetNsProp(cur, BAD_CAST"href", NULL)))) {
-		xmlChar *baseURL = xmlNodeGetBase(cur->doc, cur);
-		gchar *url, *relation, *escTitle = NULL, *title;
-		
-		if (baseURL == NULL && fp->htmlUrl != NULL && fp->htmlUrl[0] != '|' &&
-			strstr(fp->htmlUrl, "://") != NULL)
-			baseURL = xmlStrdup(BAD_CAST(fp->htmlUrl));
-		url = common_build_url(href, baseURL);
-		
-		relation = utf8_fix(xmlGetNsProp(cur, BAD_CAST"rel", NULL));
-		title = utf8_fix(xmlGetNsProp(cur, BAD_CAST"title", NULL));
-		if (title != NULL)
-			escTitle = g_markup_escape_text(title, -1);
-		/* FIXME: Display the human readable title from the property "title" */
-		/* This current code was copied from the RSS parser.*/
-		
-		if(!xmlHasNsProp(cur, BAD_CAST"rel", NULL) || relation == NULL || g_str_equal(relation, "alternate"))
-			item_set_source(ip, url);
-		else if (g_str_equal(relation, "enclosure"))
-			ip->metadata = metadata_list_append(ip->metadata, "enclosure", url);
-		else
-			/* FIXME: Maybe do something with other links such as "related" and add metadata for "via"? */;
-		xmlFree(baseURL);
-		xmlFree(title);
-		g_free(escTitle);
-		g_free(url);
-		g_free(relation);
+static void atom10_parse_entry_link(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
+	gchar *href = atom10_parse_link(cur, fp, ip, state);
+	if(href) {
+		item_set_source(ip, href);
 		g_free(href);
-	} else
-		/* FIXME: @href is required, this document is not valid Atom */;
-
+	}
 }
 
-static void atom10_parse_entry_published(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_entry_published(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	gchar *datestr = utf8_fix(xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1));
 	if(NULL != datestr) {
 		item_set_time(ip, parseISO8601Date(datestr));
@@ -326,7 +382,7 @@ static void atom10_parse_entry_published(xmlNodePtr cur, feedPtr fp, itemPtr ip,
 	}
 }
 
-static void atom10_parse_entry_rights(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_entry_rights(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	gchar *rights = atom10_parse_text_construct(cur, FALSE);
 	if(NULL != rights)
 		ip->metadata = metadata_list_append(ip->metadata, "copyright", rights);
@@ -335,7 +391,7 @@ static void atom10_parse_entry_rights(xmlNodePtr cur, feedPtr fp, itemPtr ip, st
 
 /* <summary> can be used for short text descriptions, if there is no
    <content> description we show the <summary> content */
-static void atom10_parse_entry_summary(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_entry_summary(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	gchar *summary;
 	if (NULL == item_get_description(ip)) {
 		summary = atom10_parse_text_construct(cur, TRUE);
@@ -346,14 +402,14 @@ static void atom10_parse_entry_summary(xmlNodePtr cur, feedPtr fp, itemPtr ip, s
 	}
 }
 
-static void atom10_parse_entry_title(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_entry_title(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	gchar *title = utf8_fix(atom10_parse_text_construct(cur, FALSE));
 	if (title != NULL)
 		item_set_title(ip, title);
 	g_free(title);
 }
 
-static void atom10_parse_entry_updated(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_entry_updated(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	gchar *datestr = utf8_fix(xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1));
 	if(NULL != datestr) {
 		item_set_time(ip, parseISO8601Date(datestr));
@@ -394,7 +450,7 @@ static itemPtr atom10_parse_entry(feedPtr fp, xmlNodePtr cur) {
 	cur = cur->xmlChildrenNode;
 	while (cur != NULL) {
 		
-		if (cur->type != XML_ELEMENT_NODE || cur->name == NULL) {
+		if (cur->type != XML_ELEMENT_NODE || cur->name == NULL || cur->ns == NULL) {
 			cur = cur->next;
 			continue;
 		}
@@ -410,7 +466,7 @@ static itemPtr atom10_parse_entry(feedPtr fp, xmlNodePtr cur) {
 		}
 		
 		/* check namespace of this tag */
-		if(NULL == cur->ns || NULL == cur->ns->href) {
+		if(NULL == cur->ns->href) {
 			/* This is an invalid feed... no idea what to do with the current element */
 			printf("element with no namespace found!\n");
 			cur = cur->next;
@@ -443,7 +499,7 @@ static itemPtr atom10_parse_entry(feedPtr fp, xmlNodePtr cur) {
 	return ip;
 }
 
-static void atom10_parse_feed_author(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_feed_author(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	/* parse feed author */
 	gchar *author = atom10_parse_person_construct(cur);
 	fp->metadata = metadata_list_append(fp->metadata, "author", author);
@@ -451,7 +507,7 @@ static void atom10_parse_feed_author(xmlNodePtr cur, feedPtr fp, itemPtr ip, str
 	/* FIXME: make item parsing use this author if not specified elsewhere */
 }
 
-static void atom10_parse_feed_category(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_feed_category(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	gchar *label = NULL, *escaped;
 	if (xmlHasNsProp(cur, BAD_CAST"label", NULL)) {
 		label = utf8_fix(xmlGetNsProp(cur, BAD_CAST"label", NULL));
@@ -466,15 +522,15 @@ static void atom10_parse_feed_category(xmlNodePtr cur, feedPtr fp, itemPtr ip, s
 	}
 }
 
-static void atom10_parse_feed_contributor(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_feed_contributor(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	/* parse feed contributors */
 	gchar *contributer = atom10_parse_person_construct(cur);
 	fp->metadata = metadata_list_append(fp->metadata, "contributor", contributer);
 	g_free(contributer);
 }
 
-static void atom10_parse_feed_generator(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
-	gchar *ret, *version, *tmp, *uri;
+static void atom10_parse_feed_generator(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
+	gchar *ret, *version, *tmp = "", *uri;
 	ret = unhtmlize(utf8_fix(xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1)));
 	if (ret != NULL && ret[0] != '\0') {
 		version = utf8_fix(xmlGetNsProp(cur, BAD_CAST"version", NULL));
@@ -495,77 +551,51 @@ static void atom10_parse_feed_generator(xmlNodePtr cur, feedPtr fp, itemPtr ip,
 	}
 	g_free(ret);
 }
-static void atom10_parse_feed_icon(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_feed_icon(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	/* FIXME: Parse icon and use as a favicon? */
 }
 
-static void atom10_parse_feed_id(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_feed_id(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	/* FIXME: Parse ID, but I'm not sure where Liferea would use it */
 }
 
-static void atom10_parse_feed_link(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
-	gchar *href;
-	
-	if(NULL != (href = utf8_fix(xmlGetNsProp(cur, BAD_CAST"href", NULL)))) {
-		gchar *baseURL = (gchar*)xmlNodeGetBase(cur->doc, cur);
-		gchar *url, *relation, *escTitle = NULL, *title;
-		
-		if (baseURL == NULL && fp->htmlUrl != NULL && fp->htmlUrl[0] != '|' &&
-		    strstr(fp->htmlUrl, "://") != NULL)
-			baseURL = g_strdup(fp->htmlUrl);
-		url = common_build_url(href, baseURL);
-		
-		relation = utf8_fix(xmlGetNsProp(cur, BAD_CAST"rel", NULL));
-		title = utf8_fix(xmlGetNsProp(cur, BAD_CAST"rel", NULL));
-		if (title != NULL)
-			escTitle = g_markup_escape_text(title, -1);
-		/* FIXME: Display the human readable title from the property "title" */
-		/* This current code was copied from the RSS parser.*/
-		
-		if(!xmlHasNsProp(cur, BAD_CAST"rel", NULL) || relation == NULL || g_str_equal(relation, BAD_CAST"alternate"))
-			feed_set_html_url(fp, url);
-		else if (g_str_equal(relation, "enclosure")) {
-			ip->metadata = metadata_list_append(ip->metadata, "enclosure", url);
-		} else
-			/* FIXME: Maybe do something with other links such as "related" and add metadata for "via"? */;
-		xmlFree(title);
-		xmlFree(escTitle);
-		xmlFree(baseURL);
-		g_free(url);
-		g_free(relation);
+static void atom10_parse_feed_link(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
+	gchar *href = atom10_parse_link(cur, fp, ip, state);
+	if(href) {
+		feed_set_html_url(fp, href);
 		g_free(href);
-	} 
+	}
 }
 
-static void atom10_parse_feed_logo(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_feed_logo(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	gchar *logoUrl = atom10_parse_text_construct(cur, FALSE);
 	/* FIXME: Verify URL is not evil... */
 	feed_set_image_url(fp, logoUrl);
 	g_free(logoUrl);
 }
 
-static void atom10_parse_feed_rights(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_feed_rights(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	gchar *rights = atom10_parse_text_construct(cur, FALSE);
 	if(NULL != rights)
 		fp->metadata = metadata_list_append(fp->metadata, "copyright", rights);
 	g_free(rights);
 }
 
-static void atom10_parse_feed_subtitle(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_feed_subtitle(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	gchar *subtitle = convertToHTML(atom10_parse_text_construct(cur, TRUE));
 	if (subtitle != NULL)
 		feed_set_description(fp, subtitle);
 	g_free(subtitle);				
 }
 
-static void atom10_parse_feed_title(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_feed_title(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	gchar *title = atom10_parse_text_construct(cur, FALSE);
 	if (title != NULL)
 		feed_set_title(fp, title);
 	g_free(title);
 }
 
-static void atom10_parse_feed_updated(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState state) {
+static void atom10_parse_feed_updated(xmlNodePtr cur, feedPtr fp, itemPtr ip, struct atom10ParserState *state) {
 	
 	gchar *timestamp = utf8_fix(xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1));
 	if(NULL != timestamp) {
@@ -613,7 +643,7 @@ static void atom10_parse_feed(feedPtr fp, xmlDocPtr doc, xmlNodePtr cur) {
 		/* parse feed contents */
 		cur = cur->xmlChildrenNode;
 		while(cur != NULL) {
-			if(NULL == cur->name || cur->type != XML_ELEMENT_NODE) {
+			if(NULL == cur->name || cur->type != XML_ELEMENT_NODE || cur->ns == NULL) {
 				cur = cur->next;
 				continue;
 			}
@@ -628,7 +658,7 @@ static void atom10_parse_feed(feedPtr fp, xmlDocPtr doc, xmlNodePtr cur) {
 			}
 			
 			/* check namespace of this tag */
-			if(NULL == cur->ns || cur->ns->href == NULL) {
+			if(cur->ns->href == NULL) {
 				/* This is an invalid feed... no idea what to do with the current element */
 				printf("element with no namespace found!\n");
 				cur = cur->next;
@@ -667,6 +697,8 @@ static void atom10_parse_feed(feedPtr fp, xmlDocPtr doc, xmlNodePtr cur) {
 }
 
 static gboolean atom10_format_check(xmlDocPtr doc, xmlNodePtr cur) {
+	if (cur->name == NULL || cur->ns == NULL || cur->ns->href == NULL)
+		return FALSE;
 	return xmlStrEqual(cur->name, BAD_CAST"feed") && xmlStrEqual(cur->ns->href, ATOM10_NS);
 }
 
