@@ -191,57 +191,31 @@ void unhtmlizeHandleCharacters (void *user_data, const xmlChar *string, int leng
 
 }
 
-/* Converts a UTF-8 strings containing any HTML stuff to 
-   a string without any entities or tags containing all
-   text nodes of the given HTML string. The original 
-   string will be freed. */
-gchar * unhtmlize(gchar *string) {
-	htmlSAXHandlerPtr	sax_p = NULL;
+void _unhtmlize(gchar *string, gchar *result, result_buffer *buffer) {
 	htmlParserCtxtPtr	ctxt;
-	gchar			*result;
-	result_buffer		*buffer;
-	
-	if(NULL == string)
-		return NULL;
-		
-	string = utf8_fix(string);
-
-	/* only do something if there are any entities or tags */
-	if(NULL == (strpbrk(string, "&<>")))
-		return string;
-
-	buffer = g_new0(result_buffer, 1);
-	sax_p = g_new0(htmlSAXHandler, 1);
+	htmlSAXHandlerPtr	sax_p = g_new0(htmlSAXHandler, 1);
  	sax_p->characters = unhtmlizeHandleCharacters;
-
-	/* in older versions htmlSAXParseDoc was used which caused
-	   strange crashes when freeing the parser context... */
-	   
 	ctxt = htmlCreatePushParserCtxt(sax_p, buffer, string, strlen(string), "", XML_CHAR_ENCODING_UTF8);
 	htmlParseChunk(ctxt, string, 0, 1);
 	htmlFreeParserCtxt(ctxt);
-	result = buffer->data;
-	g_free(buffer);
  	g_free(sax_p);
- 
- 	if(result == NULL || !g_utf8_strlen(result, -1)) {
- 		/* Something went wrong in the parsing.
- 		 * Use original string instead */
-		g_free(result);
- 		return string;
- 	} else {
- 		g_free(string);
- 		return result;
- 	}
+}
+
+void _unxmlize(gchar *string, gchar *result, result_buffer *buffer) {
+	xmlParserCtxtPtr	ctxt;
+	xmlSAXHandler	*sax_p = g_new0(xmlSAXHandler, 1);
+ 	sax_p->characters = unhtmlizeHandleCharacters;
+	ctxt = xmlCreatePushParserCtxt(sax_p, buffer, string, strlen(string), "");
+	xmlParseChunk(ctxt, string, 0, 1);
+	xmlFreeParserCtxt(ctxt);
+ 	g_free(sax_p);
 }
 
 /* Converts a UTF-8 strings containing any XML stuff to 
    a string without any entities or tags containing all
    text nodes of the given HTML string. The original 
    string will be freed. */
-gchar * unxmlize(gchar *string) {
-	xmlSAXHandler	*sax_p = NULL;
-	xmlParserCtxtPtr	ctxt;
+static gchar * unmarkupize(gchar *string, void(*parse)(gchar *string, gchar *result, result_buffer *buffer)) {
 	gchar			*result;
 	result_buffer		*buffer;
 	
@@ -255,18 +229,9 @@ gchar * unxmlize(gchar *string) {
 		return string;
 
 	buffer = g_new0(result_buffer, 1);
-	sax_p = g_new0(xmlSAXHandler, 1);
- 	sax_p->characters = unhtmlizeHandleCharacters;
-
-	/* in older versions htmlSAXParseDoc was used which caused
-	   strange crashes when freeing the parser context... */
-	   
-	ctxt = xmlCreatePushParserCtxt(sax_p, buffer, string, strlen(string), "");
-	xmlParseChunk(ctxt, string, 0, 1);
-	xmlFreeParserCtxt(ctxt);
+	parse(string, result, buffer);
 	result = buffer->data;
 	g_free(buffer);
- 	g_free(sax_p);
  
  	if(result == NULL || !g_utf8_strlen(result, -1)) {
  		/* Something went wrong in the parsing.
@@ -279,6 +244,9 @@ gchar * unxmlize(gchar *string) {
  	}
 }
 
+gchar * unhtmlize(gchar * string) { return unmarkupize(string, _unhtmlize); }
+gchar * unxmlize(gchar * string) { return unmarkupize(string, _unxmlize); }
+
 #define MAX_PARSE_ERROR_LINES	10
 
 /** used by bufferParseError to keep track of error messages */
@@ -565,11 +533,17 @@ time_t parseRFC822Date(gchar *date) {
 	oldlocale = g_strdup(setlocale(LC_TIME, NULL));
 	setlocale(LC_TIME, "C");
 	
-	/* standard format with 2 digit year */
-	if(NULL != (pos = strptime((const char *)date, "%d %b %y %T", &tm)))
+	/* standard format with seconds and 4 digit year */
+	if(NULL != (pos = strptime((const char *)date, " %d %b %Y %T", &tm)))
 		success = TRUE;
-	/* non-standard format with 4 digit year */
-	else if(NULL != (pos = strptime((const char *)date, "%d %b %Y %T", &tm)))
+	/* non-standard format without seconds and 4 digit year */
+	if(NULL != (pos = strptime((const char *)date, " %d %b %Y %H:%M", &tm)))
+		success = TRUE;
+	/* non-standard format with seconds and 2 digit year */
+	else if(NULL != (pos = strptime((const char *)date, " %d %b %y %T", &tm)))
+		success = TRUE;
+	/* non-standard format without seconds 2 digit year */
+	else if(NULL != (pos = strptime((const char *)date, " %d %b %y %H:%M", &tm)))
 		success = TRUE;
 	
 	while(pos != NULL && *pos != '\0' && isspace((int)*pos))       /* skip whitespaces before timezone */
@@ -813,3 +787,85 @@ gchar *strreplace(const char *string, const char *delimiter,
 	return ret;
 }
 
+typedef unsigned chartype;
+
+/* strcasestr is Copyright (C) 1994, 1996-2000, 2004 Free Software
+   Foundation, Inc.  It was taken from the GNU C Library, which is
+   licenced under the GPL v2.1 or (at your option) newer version. */
+char *liferea_strcasestr (const char *phaystack, const char *pneedle)
+{
+	register const unsigned char *haystack, *needle;
+	register chartype b, c;
+
+	haystack = (const unsigned char *) phaystack;
+	needle = (const unsigned char *) pneedle;
+
+	b = tolower(*needle);
+	if (b != '\0') {
+		haystack--;                               /* possible ANSI violation */
+		do {
+			c = *++haystack;
+			if (c == '\0')
+				goto ret0;
+		} while (tolower(c) != (int) b);
+		
+		c = tolower(*++needle);
+		if (c == '\0')
+			goto foundneedle;
+		++needle;
+		goto jin;
+		
+		for (;;) {
+			register chartype a;
+			register const unsigned char *rhaystack, *rneedle;
+			
+			do {
+				a = *++haystack;
+				if (a == '\0')
+					goto ret0;
+				if (tolower(a) == (int) b)
+					break;
+				a = *++haystack;
+				if (a == '\0')
+					goto ret0;
+			shloop:
+				;
+			}
+			while (tolower(a) != (int) b);
+			
+		jin:      a = *++haystack;
+			if (a == '\0')
+				goto ret0;
+			
+			if (tolower(a) != (int) c)
+				goto shloop;
+			
+			rhaystack = haystack-- + 1;
+			rneedle = needle;
+			a = tolower(*rneedle);
+			
+			if (tolower(*rhaystack) == (int) a)
+				do {
+					if (a == '\0')
+						goto foundneedle;
+					++rhaystack;
+					a = tolower(*++needle);
+					if (tolower(*rhaystack) != (int) a)
+						break;
+					if (a == '\0')
+						goto foundneedle;
+					++rhaystack;
+					a = tolower(*++needle);
+				} while (tolower (*rhaystack) == (int) a);
+			
+			needle = rneedle;             /* took the register-poor approach */
+			
+			if (a == '\0')
+				break;
+		}
+	}
+ foundneedle:
+	return (char*) haystack;
+ ret0:
+	return 0;
+}
