@@ -53,10 +53,10 @@
 #define STARTUP_FEED_ACTION		"/apps/liferea/startup_feed_action"
 #define UPDATE_THREAD_CONCURRENCY	"/apps/liferea/update-thread-concurrency"
 #define KEEP_FEEDS_IN_MEMORY		"/apps/liferea/keep-feeds-in-memory"
-#define DISABLE_SUBSCRIPTION_PIPE	"/apps/liferea/disable-subscription-pipe"
 
 /* folder handling settings */
 #define FOLDER_DISPLAY_MODE		"/apps/liferea/folder-display-mode"
+#define FOLDER_DISPLAY_HIDE_READ	"/apps/liferea/folder-display-hide-read"
 
 /* GUI settings and persistency values */
 #define SHOW_TRAY_ICON			"/apps/liferea/trayicon"
@@ -74,6 +74,7 @@
 #define LAST_ZOOMLEVEL			"/apps/liferea/last-zoomlevel"
 
 /* networking settings */
+#define NETWORK_TIMEOUT			"/apps/liferea/network-timeout"
 #define USE_PROXY			"/system/http_proxy/use_http_proxy"
 #define PROXY_HOST			"/system/http_proxy/host"
 #define PROXY_PORT			"/system/http_proxy/port"
