@@ -1,8 +1,8 @@
 /**
  * @file export.c OPML feedlist import&export
  *
- * Copyright (C) 2004 Nathan J. Conrad <t98502@users.sourceforge.net>
- * Copyright (C) 2004 Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2004-2005 Nathan J. Conrad <t98502@users.sourceforge.net>
+ * Copyright (C) 2004-2005 Lars Lindner <lars.lindner@gmx.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -53,6 +53,9 @@ static void append_node_tag(nodePtr ptr, gpointer userdata) {
 	rulePtr		rule;
 	
 	debug_enter("append_node_tag");
+
+	if(!internal && (FST_VFOLDER == ptr->type))
+		return;
 	
 	if(FST_FOLDER == ptr->type) {
 		folderPtr folder = (folderPtr)ptr;
@@ -123,6 +126,9 @@ static void append_node_tag(nodePtr ptr, gpointer userdata) {
 				
 			if(TRUE == feed_get_two_pane_mode(fp))
 				xmlNewProp(childNode, BAD_CAST"twoPane", BAD_CAST"true");
+
+			if(TRUE == fp->encAutoDownload)
+				xmlNewProp(childNode, BAD_CAST"encAutoDownload", BAD_CAST"true");
 		}
 		
 		/* add vfolder rules */
@@ -372,13 +378,19 @@ static void import_parse_outline(xmlNodePtr cur, folderPtr folder, gboolean trus
 			fp->sortReversed = FALSE;
 		if(sortStr != NULL)
 			xmlFree(sortStr);
-			
 		
 		tmp = xmlGetProp(cur, BAD_CAST"twoPane");
 		if(NULL != tmp && !xmlStrcmp(tmp, BAD_CAST"true"))
 			feed_set_two_pane_mode(fp, TRUE);
-		if (tmp != NULL)
+		if(tmp != NULL)
 			xmlFree(tmp);
+
+		tmp = xmlGetProp(cur, BAD_CAST"encAutoDownload");
+		if(NULL != tmp && !xmlStrcmp(tmp, BAD_CAST"true"))
+			fp->encAutoDownload = TRUE;
+		if(tmp != NULL)
+			xmlFree(tmp);
+
 		/* set feed properties available from the OPML feed list 
 		   they may be overwritten by the values of the cache file
 		   but we need them in case the cache file loading fails */
@@ -557,6 +569,6 @@ static void on_export_activate_cb(const gchar *filename, gpointer user_data) {
 
 void on_export_activate(GtkMenuItem *menuitem, gpointer user_data) {
 	
-	ui_choose_file(_("Export Feed List"), GTK_WINDOW(mainwindow), _("Export"), TRUE, on_export_activate_cb, "feedlist.opml", NULL, NULL);
+	ui_choose_file(_("Export Feed List"), GTK_WINDOW(mainwindow), _("Export"), TRUE, on_export_activate_cb, NULL, "feedlist.opml", NULL);
 }
 
