@@ -66,7 +66,7 @@ void favicon_load(feedPtr fp) {
 		
 		/* check creation date and update favicon if older than one month */
 		g_get_current_time(&now);
-		if(now.tv_sec > statinfo.st_mtime + 60*60*24*31) {
+		if(now.tv_sec > (fp->lastFaviconPoll.tv_sec + 60*60*24*31)) {
 			debug1(DEBUG_UPDATE, "updating favicon %s\n", filename);
 			favicon_download(fp);
 		}
@@ -157,37 +157,48 @@ static void favicon_download_4(feedPtr fp) {
 
 static void favicon_download_request_favicon_cb(struct request *request) {
 	feedPtr		fp = (feedPtr)request->user_data;
-	gchar		*tmp;
-	GError		*err = NULL;
 	gboolean	success = FALSE;
 	
 	debug2(DEBUG_UPDATE, "icon download processing (%s, %d bytes)", request->source, request->size);
 	fp->otherRequests = g_slist_remove(fp->otherRequests, request);
 	
 	if(NULL != request->data && request->size > 0) {
-		GdkPixbufLoader *loader = gdk_pixbuf_loader_new();
-		GdkPixbuf *pixbuf;
+		GdkPixbufLoader *loader = NULL;
+		GdkPixbuf *pixbuf = NULL;
+		GError		*err = NULL;
+		gchar		*tmp = NULL;
+
+		loader = gdk_pixbuf_loader_new(); /* This maybe should specify the mime type, but since some servers
+											 specify the wrong mime type, I'm letting it be autodetected. */
+		if (loader == NULL)
+			goto error;
+		if(!gdk_pixbuf_loader_write(loader, (guchar *)request->data, request->size, &err) || err != NULL) {
+			gdk_pixbuf_loader_close(loader, NULL);
+			goto error;
+		}
+		if(!gdk_pixbuf_loader_close(loader, &err))
+			goto error;
+		pixbuf = gdk_pixbuf_loader_get_pixbuf(loader);
+		if (pixbuf == NULL)
+			goto error;
 		tmp = common_create_cache_filename("cache" G_DIR_SEPARATOR_S "favicons", feed_get_id(fp), "png");
-		if(gdk_pixbuf_loader_write(loader, (guchar *)request->data, request->size, &err)) {
-			if(NULL != (pixbuf = gdk_pixbuf_loader_get_pixbuf(loader))) {
-				debug1(DEBUG_UPDATE, "saving icon as %s", tmp);
-				if(FALSE == (gdk_pixbuf_save(pixbuf, tmp, "png", &err, NULL))) {
-					g_warning("favicon saving error!");
-				}
+		debug1(DEBUG_UPDATE, "saving favicon as %s", tmp);
+		if(gdk_pixbuf_save(pixbuf, tmp, "png", &err, NULL)) {
 				success = TRUE;
-				favicon_load(fp);
-			}
+		} else {
+			g_warning("favicon saving error!");
 		}
 
+		favicon_load(fp);
+		ui_feed_update(fp);
+	error:
 		if(err != NULL) {
-			g_warning("%s\n", err->message);
+			g_warning("Error reading favicon %s: %s\n", request->source, err->message);
 			g_error_free(err);
 		}
-
-		gdk_pixbuf_loader_close(loader, NULL);
-		g_object_unref(loader);
+		if (loader != NULL)
+			g_object_unref(loader);
 		g_free(tmp);
-		ui_feed_update(fp);
 	}
 	
 	if(!success) {
@@ -215,7 +226,7 @@ static void favicon_download_html_request_cb(struct request *request) {
 			request2->source = iconUri;
 			request2->callback = &favicon_download_request_favicon_cb;
 			request2->user_data = fp;
-			request2->flags++;
+			request2->flags = request->flags + 1;
 			fp->otherRequests = g_slist_append(fp->otherRequests, request2);
 			download_queue(request2);
 		}
@@ -272,6 +283,7 @@ void favicon_download(feedPtr fp) {
 					     feed_get_title(fp));
 
 	g_get_current_time(&fp->lastFaviconPoll);
+	fp->needsCacheSave = TRUE;
 	
 	if(feed_get_html_url(fp) != NULL) {
 		favicon_download_html(fp, 0);
