@@ -41,7 +41,7 @@
 static int unreadCount = 0;
 static int newCount = 0;
 
-static nodePtr	selectedNode = NULL;
+static nodePtr		selectedNode = NULL;
 extern nodePtr		displayed_node;
 
 /* helper functions */
@@ -130,9 +130,10 @@ void feedlist_remove_node(nodePtr np) {
 	if(NULL == np)
 		return;
 		
-	if(np == displayed_node) {
-		itemlist_load(NULL);
+	if(np == selectedNode) {
 		ui_htmlview_clear(ui_mainwindow_get_active_htmlview());
+		itemlist_load(NULL);
+		selectedNode = NULL;
 	}
 
 	if((FST_FEED == np->type) || (FST_VFOLDER == np->type))		
@@ -258,6 +259,7 @@ static void feed_set_error_description(feedPtr fp, gint httpstatus, gint resultc
 		if(tmp2 == NULL) {
 			switch(resultcode) {
 			case NET_ERR_URL_INVALID:    tmp2 = g_strdup(_("URL is invalid")); break;
+			case NET_ERR_PROTO_INVALID:    tmp2 = g_strdup(_("Unsupported network protocol")); break;
 			case NET_ERR_UNKNOWN:
 			case NET_ERR_CONN_FAILED:
 			case NET_ERR_SOCK_ERR:       tmp2 = g_strdup(_("Error connecting to remote host")); break;
@@ -442,7 +444,7 @@ void feedlist_selection_changed(nodePtr np) {
 
 void on_menu_delete(GtkMenuItem *menuitem, gpointer user_data) {
 
-	feedlist_remove_node((nodePtr)ui_feedlist_get_selected());
+	ui_feedlist_delete_prompt((nodePtr)ui_feedlist_get_selected());
 }
 
 void on_popup_refresh_selected(gpointer callback_data, guint callback_action, GtkWidget *widget) {
@@ -503,7 +505,7 @@ void on_popup_mark_as_read(gpointer callback_data, guint callback_action, GtkWid
 
 void on_popup_delete(gpointer callback_data, guint callback_action, GtkWidget *widget) {
 	
-	feedlist_remove_node((nodePtr)callback_data);
+	ui_feedlist_delete_prompt((nodePtr)callback_data);
 }
 
 /*------------------------------------------------------------------------------*/
