@@ -45,7 +45,8 @@ itemPtr item_new(void) {
 	
 	ip = g_new0(struct item, 1);
 	ip->newStatus = TRUE;
-
+	ip->popupStatus = TRUE;
+	
 	return ip;
 }
 
@@ -61,6 +62,7 @@ void item_copy(itemPtr from, itemPtr to) {
 	to->updateStatus = from->updateStatus;
 	to->readStatus = from->readStatus;
 	to->newStatus = FALSE;
+	to->popupStatus = FALSE;
 	to->marked = from->marked;
 	to->time = from->time;
 	
@@ -86,9 +88,33 @@ void item_set_description(itemPtr ip, const gchar * description) {
 	ip->description = g_strdup(description);
 }
 
-void item_set_source(itemPtr ip, const gchar * source) { g_free(ip->source);ip->source = g_strdup(source); }
-void item_set_real_source_url(itemPtr ip, const gchar * source) { g_free(ip->real_source_url);ip->real_source_url = g_strdup(source); }
-void item_set_real_source_title(itemPtr ip, const gchar * source) { g_free(ip->real_source_title);ip->real_source_title = g_strdup(source); }
+void item_set_source(itemPtr ip, const gchar * source) { 
+
+	g_free(ip->source);
+	if(NULL != source) 
+		ip->source = g_strchomp(g_strdup(source));
+	else
+		ip->source = NULL;
+}
+
+void item_set_real_source_url(itemPtr ip, const gchar * source) { 
+
+	g_free(ip->real_source_url);
+	if(NULL != source)
+		ip->real_source_url = g_strchomp(g_strdup(source));
+	else
+		ip->real_source_url = NULL;
+}
+
+void item_set_real_source_title(itemPtr ip, const gchar * source) { 
+
+	g_free(ip->real_source_title);
+	if(NULL != source)
+		ip->real_source_title = g_strchomp(g_strdup(source));
+	else
+		ip->real_source_title = NULL;
+}
+
 void item_set_time(itemPtr ip, const time_t t) { ip->time = t; }
 
 void item_set_id(itemPtr ip, const gchar * id) {
@@ -102,63 +128,81 @@ const gchar *	item_get_description(itemPtr ip) { return (ip != NULL ? ip->descri
 const gchar *	item_get_source(itemPtr ip) { return (ip != NULL ? ip->source : NULL); }
 const gchar *	item_get_real_source_url(itemPtr ip) { return (ip != NULL ? ip->real_source_url : NULL); }
 const gchar *	item_get_real_source_title(itemPtr ip) { return (ip != NULL ? ip->real_source_title : NULL); }
-const time_t	item_get_time(itemPtr ip) { return (ip != NULL ? ip->time : 0); }
-const gboolean item_get_read_status(itemPtr ip) { return (ip != NULL ? ip->readStatus : FALSE); }
-const gboolean item_get_flag(itemPtr ip) { g_assert(ip != NULL); return ip->marked; }
-const gboolean item_get_new_status(itemPtr ip) { g_assert(ip != NULL); return ip->newStatus; }
-const gboolean item_get_update_status(itemPtr ip) { g_assert(ip != NULL); return ip->updateStatus; }
+time_t	item_get_time(itemPtr ip) { return (ip != NULL ? ip->time : 0); }
+gboolean item_get_read_status(itemPtr ip) { return (ip != NULL ? ip->readStatus : FALSE); }
+gboolean item_get_flag_status(itemPtr ip) { g_assert(ip != NULL); return ip->marked; }
+gboolean item_get_new_status(itemPtr ip) { g_assert(ip != NULL); return ip->newStatus; }
+gboolean item_get_popup_status(itemPtr ip) { g_assert(ip != NULL); return ip->popupStatus; }
+gboolean item_get_update_status(itemPtr ip) { g_assert(ip != NULL); return ip->updateStatus; }
 
-void item_set_flag(itemPtr ip, gboolean newStatus) {
+void item_set_flag_status(itemPtr ip, gboolean newFlagStatus) {
 
-	if(newStatus != ip->marked) {
-		ip->marked = newStatus;
+	if(newFlagStatus != ip->marked) {
 		if(ip->fp != NULL)
 			ip->fp->needsCacheSave = TRUE;
+			
+		ip->marked = newFlagStatus;
 	}
 }
 
-void item_set_new_status(itemPtr ip, const gboolean newStatus) { 
+void item_set_new_status(itemPtr ip, const gboolean newNewStatus) { 
 
-	if(newStatus != ip->newStatus) {
-		if(TRUE == newStatus)
-			feed_increase_new_counter((feedPtr)(ip->fp));
-		else
-			feed_decrease_new_counter((feedPtr)(ip->fp));
+	if(newNewStatus != ip->newStatus) {
+		if(ip->fp != NULL) {
+			if(TRUE == newNewStatus)
+				feed_increase_new_counter((feedPtr)(ip->fp));
+			else
+				feed_decrease_new_counter((feedPtr)(ip->fp));
+				
+			ip->fp->needsCacheSave = TRUE;
+		}	
+		ip->newStatus = newNewStatus; 
+	}
+}
+
+void item_set_popup_status(itemPtr ip, const gboolean newPopupStatus) { 
+
+	if(newPopupStatus != ip->popupStatus) {
+		if(ip->fp != NULL) {
+			if(TRUE == newPopupStatus)
+				feed_increase_popup_counter((feedPtr)(ip->fp));
+			else
+				feed_decrease_popup_counter((feedPtr)(ip->fp));
+
+			/* no need to save feed */
+		}
 			
-		ip->newStatus = newStatus; 
-		/* no need to save feed */
+		ip->popupStatus = newPopupStatus; 
 	}
 }
 
 void item_set_update_status(itemPtr ip, const gboolean newStatus) { 
 	
 	if(newStatus != ip->updateStatus) {
-		ip->updateStatus = newStatus; 
 		if(ip->fp != NULL)
 			ip->fp->needsCacheSave = TRUE;
+			
+		ip->updateStatus = newStatus; 
 	}
 }
 
 void item_set_read_status(itemPtr ip, gboolean newStatus) { 
 	
 	if(newStatus != ip->readStatus) {
-		if(FALSE == newStatus)
-			feed_increase_unread_counter((feedPtr)(ip->fp));
-		else
-			feed_decrease_unread_counter((feedPtr)(ip->fp));
+		if(ip->fp != NULL) {
+			if(FALSE == newStatus)
+				feed_increase_unread_counter((feedPtr)(ip->fp));
+			else
+				feed_decrease_unread_counter((feedPtr)(ip->fp));
 
-		ip->readStatus = newStatus;
-		if(ip->fp != NULL)
 			ip->fp->needsCacheSave = TRUE;
+		}
+		
+		ip->readStatus = newStatus;
 	}
 }
 
 void item_free(itemPtr ip) {
-	
-	if(FALSE == ip->readStatus)
-		feed_decrease_unread_counter(ip->fp);
-	if(TRUE == ip->newStatus)
-		feed_decrease_new_counter(ip->fp);
 
 	g_free(ip->title);
 	g_free(ip->source);
@@ -189,11 +233,12 @@ gchar *item_render(itemPtr ip) {
 	addToHTMLBufferFast(&buffer, HEAD_START);
 	/*  -- Feed line */
 	if(feed_get_html_url((NULL == ip->sourceFeed)?ip->fp:ip->sourceFeed) != NULL)
-		tmp = g_strdup_printf("<span class=\"feedlink\"><a href=\"%s\">%s</a></span>",
-			              feed_get_html_url((NULL == ip->sourceFeed)?ip->fp:ip->sourceFeed),
-			              feed_get_title((NULL == ip->sourceFeed)?ip->fp:ip->sourceFeed));
+		
+		tmp = g_markup_printf_escaped("<span class=\"feedlink\"><a href=\"%s\">%s</a></span>",
+									 feed_get_html_url((NULL == ip->sourceFeed)?ip->fp:ip->sourceFeed),
+									 feed_get_title((NULL == ip->sourceFeed)?ip->fp:ip->sourceFeed));
 	else
-		tmp = g_strdup_printf("<span class=\"feedlink\">%s</span>",
+		tmp = g_markup_printf_escaped("<span class=\"feedlink\">%s</span>",
 			              feed_get_title((NULL == ip->sourceFeed)?ip->fp:ip->sourceFeed));
 
 	tmp2 = g_strdup_printf(HEAD_LINE, _("Feed:"), tmp);
@@ -218,18 +263,15 @@ gchar *item_render(itemPtr ip) {
 		tmp = g_strdup_printf("<a href=\"%s\"><img class=\"favicon\" src=\"file://%s\"></a>", feed_get_html_url((NULL == ip->sourceFeed)?ip->fp:ip->sourceFeed), tmp2);
 		g_free(tmp2);
 	}
-	
+	tmp3 = g_markup_escape_text((item_get_title(ip) != NULL)?item_get_title(ip):_("[No title]"), -1);
 	if(item_get_source(ip) != NULL)
 		tmp2 = g_strdup_printf("<span class=\"itemtitle\">%s<a href=\"%s\">%s</a></span>",
-			              tmp,
-			              item_get_source(ip),
-			              (item_get_title(ip) != NULL)?item_get_title(ip):_("[No title]"));
+							   tmp, item_get_source(ip), tmp3);
 	else
-		tmp2 = g_strdup_printf("<span class=\"itemtitle\">%s%s</span>",
-			              tmp,
-			              (item_get_title(ip) != NULL)?item_get_title(ip):_("[No title]"));
-	
+		tmp2 = g_strdup_printf("<span class=\"itemtitle\">%s%s</span>", tmp,tmp3);
 	g_free(tmp);
+	g_free(tmp3);
+	
 	tmp = g_strdup_printf(HEAD_LINE, _("Item:"), tmp2);
 	g_free(tmp2);
 	addToHTMLBufferFast(&buffer, tmp);
@@ -238,11 +280,11 @@ gchar *item_render(itemPtr ip) {
 	/*  -- real source line */
 	tmp = NULL;
 	if(item_get_real_source_url(ip) != NULL)
-		tmp = g_strdup_printf("<span class=\"itemsource\"><a href=\"%s\">%s</a></span>",
+		tmp = g_markup_printf_escaped("<span class=\"itemsource\"><a href=\"%s\">%s</a></span>",
 			              item_get_real_source_url(ip),
 			              (item_get_real_source_title(ip) != NULL)? item_get_real_source_title(ip) : _("[No title]"));
 	else if(item_get_real_source_title(ip) != NULL)
-		tmp = g_strdup_printf("<span class=\"itemsource\">%s</span>",
+		tmp = g_markup_printf_escaped("<span class=\"itemsource\">%s</span>",
 			              item_get_real_source_title(ip));
 
 	if(NULL != tmp) {
@@ -333,6 +375,7 @@ itemPtr item_parse_cache(xmlDocPtr doc, xmlNodePtr cur) {
 	g_assert(NULL != cur);
 	
 	ip = item_new();
+	ip->popupStatus = FALSE;
 	ip->newStatus = FALSE;
 	
 	cur = cur->xmlChildrenNode;
@@ -365,16 +408,17 @@ itemPtr item_parse_cache(xmlDocPtr doc, xmlNodePtr cur) {
 		else if(!xmlStrcmp(cur->name, BAD_CAST"nr"))
 			ip->nr = atol(tmp);
 
+		else if(!xmlStrcmp(cur->name, BAD_CAST"newStatus"))
+			item_set_new_status(ip, (0 == atoi(tmp))?FALSE:TRUE);
+			
 		else if(!xmlStrcmp(cur->name, BAD_CAST"readStatus"))
-			ip->readStatus = (0 == atoi(tmp))?FALSE:TRUE;
+			item_set_read_status(ip, (0 == atoi(tmp))?FALSE:TRUE);
 			
 		else if(!xmlStrcmp(cur->name, BAD_CAST"updateStatus"))
-			ip->updateStatus = (0 == atoi(tmp))?FALSE:TRUE;
+			item_set_update_status(ip, (0 == atoi(tmp))?FALSE:TRUE);
 
 		else if(!xmlStrcmp(cur->name, BAD_CAST"mark")) 
-			/* we don't call item_set_mark here because it would
-			 * update the UI */
-			ip->marked = (1 == atoi(tmp))?TRUE:FALSE;
+			item_set_flag_status(ip, (1 == atoi(tmp))?TRUE:FALSE);
 			
 		else if(!xmlStrcmp(cur->name, BAD_CAST"time"))
 			item_set_time(ip, atol(tmp));
@@ -419,6 +463,10 @@ void item_save(itemPtr ip, xmlNodePtr feedNode) {
 		xmlNewTextChild(itemNode, NULL, "nr", tmp);
 		g_free(tmp);
 
+		tmp = g_strdup_printf("%d", (TRUE == item_get_new_status(ip))?1:0);
+		xmlNewTextChild(itemNode, NULL, "newStatus", tmp);
+		g_free(tmp);
+
 		tmp = g_strdup_printf("%d", (TRUE == item_get_read_status(ip))?1:0);
 		xmlNewTextChild(itemNode, NULL, "readStatus", tmp);
 		g_free(tmp);
@@ -427,7 +475,7 @@ void item_save(itemPtr ip, xmlNodePtr feedNode) {
 		xmlNewTextChild(itemNode, NULL, "updateStatus", tmp);
 		g_free(tmp);
 
-		tmp = g_strdup_printf("%d", (TRUE == item_get_flag(ip))?1:0);
+		tmp = g_strdup_printf("%d", (TRUE == item_get_flag_status(ip))?1:0);
 		xmlNewTextChild(itemNode, NULL, "mark", tmp);
 		g_free(tmp);
 
