@@ -36,7 +36,8 @@ struct feed;
 typedef struct item {
 	/* those fields should not be accessed directly. Accessors are provided. */
 	gboolean 	readStatus;		/**< TRUE if the item has been read */
-	gboolean	newStatus;		/**< TRUE if the item was downloaded and not yet displayed by notification features */
+	gboolean	newStatus;		/**< TRUE if the item was downloaded and is to be counted by the tray icon */
+	gboolean	popupStatus;		/**< TRUE if the item was downloaded and is yet to be displayed by the popup notification feature */
 	gboolean	updateStatus;		/**< TRUE if the item content was updated */
 	gboolean 	marked;			/**< TRUE if the item has been marked */
 	gchar		*title;			/**< item title */
@@ -101,15 +102,17 @@ const gchar *	item_get_real_source_url(itemPtr ip);
 /** Returns the real source title of ip. */
 const gchar *	item_get_real_source_title(itemPtr ip);
 /** Returns the modification time of ip. */
-const time_t	item_get_time(itemPtr ip);
+time_t	item_get_time(itemPtr ip);
 /** Returns the flag status of ip */
-const gboolean	item_get_flag(itemPtr ip);
+gboolean	item_get_flag_status(itemPtr ip);
 /** Returns the read status of ip. */
-const gboolean	item_get_read_status(itemPtr ip);
+gboolean	item_get_read_status(itemPtr ip);
 /** Returns the new flag of ip. */
-const gboolean	item_get_new_status(itemPtr ip);
+gboolean	item_get_new_status(itemPtr ip);
+/** Returns the popup flag of ip. */
+gboolean	item_get_popup_status(itemPtr ip);
 /** Returns the update flag of ip. */
-const gboolean	item_get_update_status(itemPtr ip);
+gboolean	item_get_update_status(itemPtr ip);
 
 /** Sets the ip's title */
 void		item_set_title(itemPtr ip, const gchar * title);
@@ -129,18 +132,22 @@ void		item_set_id(itemPtr ip, const gchar * id);
 void 		item_set_read_status(itemPtr ip, gboolean newStatus);
 /** Sets the ip's new flag */
 void 		item_set_new_status(itemPtr ip, const gboolean newStatus);
+/** Sets the ip's popup flag */
+void 		item_set_popupp_status(itemPtr ip, const gboolean newPopupStatus);
 /** Sets the ip's update flag */
 void 		item_set_update_status(itemPtr ip, const gboolean newStatus);
+/** Set the popup status of an item */
+void item_set_popup_status(itemPtr ip, const gboolean newPopupStatus);
 
 /**
  * Marks ip as marked or unmarked and updates the UI to reflect this
  * change.
  *
  * @param ip item to be marked or unmarked
- * @param newStatus set to TRUE if the item is to be marked, or FALSE to
+ * @param newFlagStatus set to TRUE if the item is to be marked, or FALSE to
  * unmark the item
  */
-void	item_set_flag(itemPtr ip, const gboolean newStatus);
+void	item_set_flag_status(itemPtr ip, const gboolean newFlagStatus);
 
 /**
  * Parse an xml tree and return a new itempointer generated 
