@@ -46,13 +46,31 @@ static gint disableSortingSaving;
 
 static gboolean deferred_item_remove = FALSE;
 
+static void itemlist_check_for_deferred_removal(void) {
+	itemPtr ip;
+
+	if(NULL != displayed_item) {
+		ip = displayed_item;
+		displayed_item = NULL;
+		if(TRUE == deferred_item_remove) {
+			deferred_item_remove = FALSE;
+			itemlist_remove_item(ip);
+		}
+	}
+}
+
 static void itemlist_load_feed(feedPtr fp, gpointer data) {
 	gboolean	merge = GPOINTER_TO_INT(data);
+	gboolean	loadReadItems = TRUE;
 	GSList		*item, *itemlist;
 	itemPtr		ip;
 	
+	if(FST_FOLDER == displayed_node->type)
+		loadReadItems = !getBooleanConfValue(FOLDER_DISPLAY_HIDE_READ);
+
 	/* load model */
 	feedlist_load_feed(fp);
+
 	/* update itemlist in view */	
 	itemlist = feed_get_item_list(fp);
 	itemlist = g_slist_copy(itemlist);
@@ -61,7 +79,10 @@ static void itemlist_load_feed(feedPtr fp, gpointer data) {
 	while(NULL != item) {
 		ip = item->data;
 		g_assert(NULL != ip);
-		ui_itemlist_add_item(ip, merge);
+
+		if((FALSE == ip->readStatus) || (TRUE == loadReadItems))
+			ui_itemlist_add_item(ip, merge);
+
 		item = g_slist_next(item);
 	}
 	g_slist_free(itemlist);	
@@ -82,7 +103,7 @@ void itemlist_reload(nodePtr node) {
 	gboolean	isFeed;
 	gboolean	isFolder;
 	
-	if (displayed_node == NULL)
+	if(displayed_node == NULL)
 		return; /* Nothing to do if nothing is displayed */
 	
 	/* determine what node type is actually selected */
@@ -122,7 +143,10 @@ void itemlist_load(nodePtr node) {
 	GtkTreeModel	*model;
 	gboolean	isFeed;
 	gboolean	isFolder;
-
+	gint		sortColumn;
+	GtkSortType	sortType;
+	gboolean	sorted;
+	
 	/* Postprocessing for previously selected node, this is necessary
 	   to realize reliable read marking when using condensed mode. It's
 	   important to do this only when the selection really changed. */
@@ -137,31 +161,28 @@ void itemlist_load(nodePtr node) {
 	if(isFolder && (0 == getNumericConfValue(FOLDER_DISPLAY_MODE)))
 		return;
 	
+	itemlist_check_for_deferred_removal();
+
 	/* preparation done, we can select it... */
 	displayed_node = node;
+	displayed_item = NULL;
 
 	if(!isFeed && !isFolder) {
 		ui_itemlist_clear();
 		displayed_node = NULL;
-		displayed_item = NULL;
 		return;
 	}
 	
-	
 	model = GTK_TREE_MODEL(ui_itemlist_get_tree_store());
+	sorted = gtk_tree_sortable_get_sort_column_id(GTK_TREE_SORTABLE(model), &sortColumn, &sortType);
 	
-	if(isFeed) {
-		disableSortingSaving++;
-		gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(model), ((feedPtr)node)->sortColumn, ((feedPtr)node)->sortReversed?GTK_SORT_DESCENDING:GTK_SORT_ASCENDING);
-		disableSortingSaving--;
-	}
+	/* free the old itemstore and create a new one; this is the only way to disable sorting */
+	ui_itemlist_reset_tree_store();	 /* this also clears the itemlist. */
+	model = GTK_TREE_MODEL(ui_itemlist_get_tree_store());
 	
 	if(isFolder)
 		itemlist_set_two_pane_mode(FALSE);
 		
-	ui_itemlist_clear();
-	/* explicitly no ui_htmlview_clear() !!! */
-	displayed_item = NULL;
 
 	if(!getBooleanConfValue(KEEP_FEEDS_IN_MEMORY)) {
 		debug0(DEBUG_CACHE, "unloading everything...");
@@ -170,6 +191,17 @@ void itemlist_load(nodePtr node) {
 	
 	itemlist_reload(node);
 	ui_itemlist_enable_favicon_column((FST_VFOLDER == node->type) || (FST_FOLDER == node->type));
+	
+	/* Enable sorting */
+	if(isFeed) {
+		disableSortingSaving++;
+		gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(model), ((feedPtr)node)->sortColumn, ((feedPtr)node)->sortReversed?GTK_SORT_DESCENDING:GTK_SORT_ASCENDING);
+		disableSortingSaving--;
+	} else if (sorted ) { /* Use what had been used */
+		gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(model), sortColumn, sortType);
+	}
+	
+
 	ui_itemlist_prefocus();
 }
 
@@ -361,14 +393,7 @@ void on_itemlist_selection_changed(GtkTreeSelection *selection, gpointer data) {
 	if(!itemlist_loading && (FALSE == ui_itemlist_get_two_pane_mode())) {
 		/* vfolder postprocessing to remove unselected items not
 		   more matching the rules because they have changed state */
-		if(NULL != displayed_item) {
-			ip = displayed_item;
-			displayed_item = NULL;
-			if(TRUE == deferred_item_remove) {
-				deferred_item_remove = FALSE;
-				itemlist_remove_item(ip);
-			}
-		}
+		itemlist_check_for_deferred_removal();
 	
 		if(gtk_tree_selection_get_selected(selection, &model, &iter)) {
 			displayed_item = ip = ui_itemlist_get_item_from_iter(&iter);
