@@ -51,12 +51,10 @@
 #include "ui_htmlview.h"
 #include "update.h"
 #include "debug.h"
-#include "ui_queue.h"
 #include "ui_mainwindow.h"
 #include "metadata.h"
 #include "ui_session.h"
 
-GThread	*mainThread = NULL;
 gboolean lifereaStarted = FALSE;
 
 static void show_help(void) {
@@ -102,7 +100,7 @@ static gboolean main_lock() {
 	if (gethostname(hostname, 256) == -1)
 		return -2; /* Skip locking if this happens, which it should not.... */
 	hostname[255] = '\0';
-	filename = g_strdup_printf("%s" G_DIR_SEPARATOR_S "lock-%s:%d", common_get_cache_path(), hostname, getpid());
+	filename = g_strdup_printf("%s" G_DIR_SEPARATOR_S "lock-%s.%d", common_get_cache_path(), hostname, getpid());
 	retval = fd = open(filename, O_CREAT|O_EXCL, S_IRUSR | S_IWUSR);
 	if (fd == -1) {
 		g_free(filename);
@@ -111,42 +109,46 @@ static gboolean main_lock() {
 	
 	filename2 = g_strdup_printf("%s" G_DIR_SEPARATOR_S "lock", common_get_cache_path());
 	if (-1 == symlink(filename, filename2)) {
-		if (errno == EEXIST) {
-			if ((len = readlink(filename2, tmp, 299)) == -1)
-				retval = -2;
-			else {
-				tmp[len] = '\0';
-				host = tmp;
-				while (*host != '\0' && *host != '-') /* Step host to point to the dash */
-					host = &(host[1]);
-				if (*host == '\0')
-					retval = -3;
-				else {
-					host = &(host[1]);
-					pidstr = host;
-					while (*pidstr != '\0' && *pidstr != ':') /* Step pidstr to point to the colon */
-						pidstr = &(pidstr[1]);
-					if (*pidstr == '\0')
-						retval = -3;
-					else {
-						*pidstr = '\0';
-						pidstr = &(pidstr[1]);
-						if (!strcmp(hostname, host)) {
-							pid = atoi(pidstr); /* get PID */
-							if (kill(pid, 0) == 0 || errno != ESRCH)
-								retval = -1;
-							else
-								retval = -3;
-						} else
-							retval = -1;
-					}
-				}
-			}
-		} else 
+		if (errno != EEXIST) {
 			retval = -2;
+			goto main_lock_out;
+		}
+		if ((len = readlink(filename2, tmp, 299)) == -1) {
+			retval = -2; /* Unreadable link, or not a link */
+			goto main_lock_out;
+		}
+		host = strrchr(tmp,'/');
+		if (host == NULL) {
+			retval = -3;
+			goto main_lock_out;
+		}
+		host = strstr(host, "lock-");
+		if (host == NULL) { /* Invalid lock file */
+			retval = -3;
+			goto main_lock_out;
+		}
+		host += strlen("lock-");
+		pidstr = strrchr(host,'.');
+		if (pidstr == NULL) { /* Invalid lock file*/
+			retval = -3;
+			goto main_lock_out;
+		}
+		/* Correct lockfile format */
+		*pidstr = '\0';
+		pidstr++;
+		
+		if (!strcmp(hostname, host)) {
+			pid = atoi(pidstr); /* get PID */
+			if (kill(pid, 0) == 0 || errno != ESRCH)
+				retval = -1;
+			else
+				retval = -3;
+		} else
+			retval = -1;
 	}
-
+ main_lock_out:
 	if (retval == -3) { /* Stale lockfile */
+		fprintf(stderr,"A stale lockfile has been found, and was deleted.\n");
 		unlink(filename2);
 		symlink(filename, filename2); /* Hopefully this will work. If not, screw it. */
 	}
@@ -183,6 +185,11 @@ int main(int argc, char *argv[]) {
 	setlocale(LC_ALL, "");
 #endif
 
+	g_set_prgname("liferea");
+	gtk_set_locale();
+	g_thread_init(NULL);
+	gtk_init(&argc, &argv);
+	
 	/* parse arguments  */
 	debug_flags = 0;
 	for(i = 1; i < argc; ++i) {
@@ -239,13 +246,6 @@ int main(int argc, char *argv[]) {
 	}
 	set_debug_level(debug_flags);
 
-	g_set_prgname("liferea");
-	gtk_set_locale();
-	g_thread_init(NULL);
-	gdk_threads_init();	
-	gtk_init(&argc, &argv);
-	mainThread = g_thread_self();	/* we need to know this for locking in ui_queue.c */
-
 	add_pixmap_directory(PACKAGE_DATA_DIR G_DIR_SEPARATOR_S PACKAGE G_DIR_SEPARATOR_S "pixmaps");
 
 	if(main_lock() == -1) {
@@ -256,14 +256,10 @@ int main(int argc, char *argv[]) {
 								  _("Another copy of Liferea was found to be running. Please use it instead. "
 								  "If there is no other copy of Liferea running, please delete the "
 								  "\"~/.liferea/lock\" lock file."));
-		gdk_threads_enter();
 		gtk_dialog_run(GTK_DIALOG (dialog));
-		gdk_threads_leave();
 		gtk_widget_destroy(dialog);
 
 	} else {
-		ui_queue_init();		/* set up callback queue for other threads */
-		
 		/* order is important! */
 		conf_init();			/* initialize gconf */
 		ui_htmlview_init();		/* setup HTML widgets */
@@ -281,10 +277,12 @@ int main(int argc, char *argv[]) {
 		session_set_cmd(NULL, mainwindowState);
 #endif
 		
-		gdk_threads_enter();
+		/* Note: we explicitely do not use the gdk_thread_*
+		   locking in Liferea because it freezes the program
+		   when running Flash applets in gtkmozembed */
+
 		lifereaStarted = TRUE;
 		gtk_main();
-		gdk_threads_leave();
 	}
 
 	return 0;
