@@ -86,22 +86,44 @@ static void mozilla_write(GtkWidget *widget, const gchar *string, guint length,
  * mozembed_new_window_cb: GTKMOZEMBED SIGNAL, emitted any time a new 
  * window is requested by the document 
  */
-static void mozembed_new_window_cb(GtkMozEmbed *dummy, GtkMozEmbed **retval, guint chrome_mask, gpointer embed) {
+static void mozembed_new_window_cb(GtkMozEmbed *embed, GtkMozEmbed **newEmbed, guint chrome_mask, gpointer callback_data) {
 
 	/* The only time we want to react on new window requests
 	   is when the user clicks a link that wants to open in
 	   a new window. The following check might not be fully
 	   correct (e.g. on initial webpage loading when new popups
 	   are requested and the user crosses a link)  */
+	*newEmbed = NULL;
 	if(NULL != selectedURL) {
 		if(getBooleanConfValue(BROWSE_INSIDE_APPLICATION))
-			ui_tabs_new(selectedURL, selectedURL, FALSE);
+			*newEmbed = GTK_MOZ_EMBED(ui_tabs_new(NULL, NULL, TRUE));
 		else
 			ui_htmlview_launch_in_external_browser(selectedURL);
 	}
-	*retval = NULL;
 }
 
+static void mozembed_title_changed_cb (GtkMozEmbed *embed, gpointer user_data)
+{
+	char *newTitle;
+	newTitle = gtk_moz_embed_get_title(embed);
+	if (newTitle) {
+		ui_tabs_set_title(GTK_WIDGET(user_data), newTitle);
+		g_free(newTitle);
+	}
+}
+
+static void mozembed_location_changed_cb (GtkMozEmbed *embed, gpointer user_data) {
+	gchar *newLocation;
+	
+	newLocation = gtk_moz_embed_get_location(embed);
+	if (newLocation != NULL)
+		ui_tabs_set_location(GTK_WIDGET(embed), newLocation);
+	g_free(newLocation);
+}
+
+void mozembed_destroy_brsr_cb(GtkMozEmbed *embed, gpointer user_data) {
+	ui_tabs_close_tab(GTK_WIDGET(embed));
+}
 /**
  * mozembed_link_message_cb: GTKMOZEMBED SIGNAL, emitted when the 
  * link message changes
@@ -193,8 +215,8 @@ static GtkWidget * mozilla_create(gboolean forceInternalBrowsing) {
 	}
 	signal_connections[] =
 	{
-		/*{ "location",        mozembed_location_changed_cb  },*/
-		/*{ "title",           mozembed_title_changed_cb     },*/
+		{ "location",        mozembed_location_changed_cb  },
+		{ "title",           mozembed_title_changed_cb     },
 		/*{ "net_start",       mozembed_load_started_cb      },*/
 		/*{ "net_stop",        mozembed_load_finished_cb     },*/
 		/*{ "net_state_all",   mozembed_net_status_change_cb },*/
@@ -202,7 +224,7 @@ static GtkWidget * mozilla_create(gboolean forceInternalBrowsing) {
 		{ "link_message",    mozembed_link_message_cb      },
 		/*{ "js_status",       mozembed_js_status_cb         },*/
 		/*{ "visibility",      mozembed_visibility_cb        },*/
-		/*{ "destroy_browser", mozembed_destroy_brsr_cb      },*/
+		{ "destroy_browser", mozembed_destroy_brsr_cb      },
 		/*{ "dom_mouse_down",  mozembed_dom_mouse_down_cb    },*/
 		{ "dom_mouse_click", mozembed_dom_mouse_click_cb   },
 		{ "dom_key_press",   mozembed_dom_key_press_cb     },
@@ -238,7 +260,8 @@ static void mozilla_init() {
 	/* some GtkMozEmbed initialization taken from embed.c from the Galeon sources */
 	
 	/* init mozilla home */
-	gtk_moz_embed_set_comp_path((char *)g_getenv("MOZILLA_FIVE_HOME"));
+	g_unsetenv("MOZILLA_FIVE_HOME");
+	gtk_moz_embed_set_comp_path(NULL);
 
 	/* set a path for the profile */
 	profile = g_build_filename(g_get_home_dir(), ".liferea/mozilla", NULL);
