@@ -58,7 +58,7 @@ static GdkPixbuf* ui_feed_get_icon(feedPtr fp) {
 /** updating of a single feed list entry */
 void ui_feed_update(feedPtr fp) {
 	GtkTreeIter	iter;
-	gchar		*label, *tmp;
+	gchar		*label;
 	int		count;
 	
 	if(fp->ui_data == NULL)
@@ -69,15 +69,11 @@ void ui_feed_update(feedPtr fp) {
 	g_assert(FST_FOLDER != fp->type);
 	
 	count = feed_get_unread_counter(fp);
-	label = unhtmlize(g_strdup(feed_get_title(fp)));
-	/* FIXME: Unescape text here! */
-	tmp = g_markup_escape_text(label,-1);
-	g_free(label);
+	
 	if(count > 0)
-		label = g_strdup_printf("<span weight=\"bold\">%s (%d)</span>", tmp, count);
+		label = g_markup_printf_escaped("<span weight=\"bold\">%s (%d)</span>", feed_get_title(fp), count);
 	else
-		label = g_strdup_printf("%s", tmp);
-	g_free(tmp);
+		label = g_markup_printf_escaped("%s", feed_get_title(fp));
 	
 	gtk_tree_store_set(feedstore, &iter, FS_LABEL, label,
 	                                    FS_UNREAD, count,
@@ -169,19 +165,19 @@ static gchar * ui_feed_dialog_decode_source(struct fp_prop_ui_data *ui_data) {
 static void on_authdialog_response(GtkDialog *dialog, gint response_id, gpointer user_data) {
 	struct fp_prop_ui_data *ui_data = (struct fp_prop_ui_data*)user_data;
 
-	if (response_id == GTK_RESPONSE_OK) {
+	if(response_id == GTK_RESPONSE_OK) {
 		xmlURIPtr uri;
 		xmlChar *user, *pass, *sourceUrl;
 
 		/* Source */
 		uri = xmlParseURI(BAD_CAST feed_get_source(ui_data->fp));
 		
-		if (uri == NULL) {
-			/* FIXME: message dialog to tell user that something very unexpected happened. */
+		if(uri == NULL) {
+			g_warning("Error when parsing authentication URL! Authentication settings lost.");
 			g_free(ui_data);
 			return;
 		}
-		if (uri->user != NULL)
+		if(uri->user != NULL)
 			xmlFree(uri->user);
 
 		user = BAD_CAST gtk_entry_get_text(GTK_ENTRY(ui_data->username));
@@ -189,7 +185,7 @@ static void on_authdialog_response(GtkDialog *dialog, gint response_id, gpointer
 		uri->user = g_strdup_printf("%s:%s", user, pass);
 
 		sourceUrl = xmlSaveUri(uri);
-		if (sourceUrl != NULL) {
+		if(sourceUrl != NULL) {
 			feed_set_source(ui_data->fp, sourceUrl);
 			xmlFree(sourceUrl);
 		}
@@ -198,7 +194,6 @@ static void on_authdialog_response(GtkDialog *dialog, gint response_id, gpointer
 		xmlFreeURI(uri);
 	}
 
-
 	gtk_widget_destroy(GTK_WIDGET(dialog));
 	g_free(ui_data);
 }
@@ -285,6 +280,9 @@ static void on_propdialog_response(GtkDialog *dialog, gint response_id, gpointer
 		else if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(GTK_WIDGET(dialog), "feedCacheLimited"))))
 			ui_data->fp->cacheLimit = gtk_spin_button_get_value(GTK_SPIN_BUTTON(lookup_widget(GTK_WIDGET(dialog), "cacheItemLimit")));
 
+		/* Enclosures */
+		ui_data->fp->encAutoDownload = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(GTK_WIDGET(dialog), "enclosureDownloadCheck")));
+
 		ui_feedlist_update();
 		conf_feedlist_schedule_save();
 		if(needsUpdate)
@@ -363,7 +361,7 @@ static void on_selectfile_pressed(GtkButton *button, gpointer user_data) {
 	}
 	
 	name = g_filename_from_utf8(utfname,-1,NULL, NULL, NULL);
-	ui_choose_file(_("Choose File"), GTK_WINDOW(ui_data->dialog), GTK_STOCK_OPEN, FALSE, on_selectfileok_clicked, name, name, ui_data);
+	ui_choose_file(_("Choose File"), GTK_WINDOW(ui_data->dialog), GTK_STOCK_OPEN, FALSE, on_selectfileok_clicked, name, NULL, ui_data);
 	g_free(name);
 }
  
@@ -422,10 +420,10 @@ GtkWidget* ui_feed_authdialog_new(GtkWindow *parent, feedPtr fp, gint flags) {
 	}
 	
 	promptStr = g_strdup_printf(_("Enter the username and password for \"%s\" (%s):"),
-						   feed_get_title(fp), (source != NULL) ? source : _("Unknown source"));
+	                            feed_get_title(fp), (source != NULL) ? source : _("Unknown source"));
 	gtk_label_set_text(GTK_LABEL(lookup_widget(authdialog, "prompt")), promptStr);
 	g_free(promptStr);
-	if (source != NULL)
+	if(source != NULL)
 		xmlFree(source);
 	
 	g_signal_connect(G_OBJECT(authdialog), "response",
@@ -625,6 +623,12 @@ GtkWidget* ui_feed_propdialog_new(GtkWindow *parent, feedPtr fp) {
 
 	gtk_widget_show_all(propdialog);
 	on_feed_prop_filtercheck(GTK_TOGGLE_BUTTON(lookup_widget(propdialog, "filterCheckbox")), ui_data);
+
+	/***********************************************************************
+	 * Enclosures                                                          *
+	 **********************************************************************/
 	
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(propdialog, "enclosureDownloadCheck")), fp->encAutoDownload);
+
 	return propdialog;
 }
