@@ -45,7 +45,6 @@
 #include "favicon.h"
 #include "debug.h"
 #include "ui_tabs.h"
-#include "ui_queue.h"
 
 extern GtkWidget	*mainwindow;
 extern GHashTable	*feedHandler;
@@ -233,7 +232,10 @@ static gboolean ui_feedlist_key_press_cb(GtkWidget *widget, GdkEventKey *event,
 		nodePtr np = ui_feedlist_get_selected();
 		
 		if(NULL != np) {
-			ui_feedlist_delete(np);
+			if(event->state & GDK_SHIFT_MASK)
+				ui_feedlist_remove_node(np);
+			else
+				ui_feedlist_delete_prompt(np);
 			return TRUE;
 		}
 	}
@@ -384,9 +386,9 @@ void ui_feedlist_select(nodePtr np) {
 /*------------------------------------------------------------------------------*/
 
 enum scanStateType {
-  UNREAD_SCAN_INIT,            /* selected not yet passed */
-  UNREAD_SCAN_FOUND_SELECTED,  /* selected passed */
-  UNREAD_SCAN_SECOND_PASS      /* no unread items after selected feed */
+	UNREAD_SCAN_INIT,            /* selected not yet passed */
+	UNREAD_SCAN_FOUND_SELECTED,  /* selected passed */
+	UNREAD_SCAN_SECOND_PASS      /* no unread items after selected feed */
 };
 
 static enum scanStateType scanState = UNREAD_SCAN_INIT;
@@ -400,15 +402,15 @@ static feedPtr ui_feedlist_unread_scan(nodePtr folder) {
 	feedPtr			fp;
 	nodePtr			ptr, selectedNode;
 	GtkTreeModel		*model;
-	GtkTreeIter		iter, iter2, *selectedIter, *parent = NULL;
+	GtkTreeIter		iter, iter2, *selectedIter = NULL, *parent = NULL;
 	gboolean		valid = FALSE;
 	gint			count;
 
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(lookup_widget(mainwindow, "feedlist")));
 	if(NULL != (selectedNode = ui_feedlist_get_selected())) {
-	  selectedIter = &((ui_data *)(selectedNode->ui_data))->row;
+		selectedIter = &((ui_data *)(selectedNode->ui_data))->row;
 	} else {
-	  scanState = UNREAD_SCAN_SECOND_PASS;
+		scanState = UNREAD_SCAN_SECOND_PASS;
 	}
 
 	if(folder != NULL) {
@@ -432,12 +434,12 @@ static feedPtr ui_feedlist_unread_scan(nodePtr folder) {
 		                   -1);
 
 		if(ptr == selectedNode)
-		  scanState = UNREAD_SCAN_FOUND_SELECTED;
+			scanState = UNREAD_SCAN_FOUND_SELECTED;
 
 		/* feed match if beyond the selected feed or in second pass... */
 		if((scanState != UNREAD_SCAN_INIT) && (count > 0) &&
-		   ((FST_FEED == ptr->type) || (FST_VFOLDER == ptr->type))) {
-		       return (feedPtr)ptr;
+		   (FST_FEED == ptr->type)) {
+			return (feedPtr)ptr;
 		}
 
 		/* folder traversal if we are searching the selected feed
@@ -446,24 +448,24 @@ static feedPtr ui_feedlist_unread_scan(nodePtr folder) {
 		   feeds with unread items... */
 		if((FST_FOLDER == ptr->type) &&
 		   (((scanState != UNREAD_SCAN_INIT) && (count > 0)) ||
-		    gtk_tree_store_is_ancestor(GTK_TREE_STORE(model), &iter, selectedIter))) {
-		       if(NULL != (fp = ui_feedlist_unread_scan(ptr)))
-			 return fp;
+		    ((NULL != selectedIter) && gtk_tree_store_is_ancestor(GTK_TREE_STORE(model), &iter, selectedIter)))) {
+			if(NULL != (fp = ui_feedlist_unread_scan(ptr)))
+				return fp;
 		} /* Directories are never checked */
 
 		valid = gtk_tree_model_iter_next(model, &iter);
 	}
 
 	if(NULL == folder) { /* we are on feed list root but didn't find anything */
-	  if(0 == feedlist_get_unread_item_count()) {
-	    /* this may mean there is nothing more to find */
-	  } else {
-	    /* or that we just didn't find anything after the selected feed */
-	    g_assert(scanState != UNREAD_SCAN_SECOND_PASS);
-	    scanState = UNREAD_SCAN_SECOND_PASS;
-	    fp = ui_feedlist_unread_scan(NULL);
-	    return fp;
-	  }
+		if(0 == feedlist_get_unread_item_count()) {
+			/* this may mean there is nothing more to find */
+		} else {
+			/* or that we just didn't find anything after the selected feed */
+			g_assert(scanState != UNREAD_SCAN_SECOND_PASS);
+			scanState = UNREAD_SCAN_SECOND_PASS;
+			fp = ui_feedlist_unread_scan(NULL);
+			return fp;
+		}
 	}
 
 	return NULL;
@@ -471,8 +473,8 @@ static feedPtr ui_feedlist_unread_scan(nodePtr folder) {
 
 feedPtr ui_feedlist_find_unread_feed(nodePtr folder) {
 
-  scanState = UNREAD_SCAN_INIT;
-  return ui_feedlist_unread_scan(folder);
+	scanState = UNREAD_SCAN_INIT;
+	return ui_feedlist_unread_scan(folder);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -500,21 +502,25 @@ void on_filter_feeds_without_unread_headlines_activate(GtkMenuItem *menuitem, gp
 /*------------------------------------------------------------------------------*/
 
 static void ui_feedlist_delete_response_cb(GtkDialog *dialog, gint response_id, gpointer user_data) {
-	
+
 	switch(response_id) {
 		case GTK_RESPONSE_YES:
-			ui_feedlist_select(NULL);
-			itemlist_load(NULL);
-			feedlist_remove_node((nodePtr)user_data);
+			ui_feedlist_remove_node((nodePtr)user_data);
 			break;
 	}
 	gtk_widget_destroy(GTK_WIDGET(dialog));
 }
 
-void ui_feedlist_delete(nodePtr np) {
+void ui_feedlist_remove_node(nodePtr node) {
+
+	ui_feedlist_select(NULL);
+	feedlist_remove_node(node);
+}
+
+void ui_feedlist_delete_prompt(nodePtr np) {
 	GtkWidget *dialog;
 	gchar *text;
-	
+
 	g_assert(np != NULL);
 	g_assert(np->ui_data != NULL);
 	g_assert(np == ui_feedlist_get_selected());
@@ -537,7 +543,7 @@ void ui_feedlist_delete(nodePtr np) {
 	gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(mainwindow));
 
 	g_free(text);
-	
+
 	gtk_widget_show_all(dialog);
 
 	g_signal_connect(G_OBJECT(dialog), "response",
@@ -550,11 +556,15 @@ void ui_feedlist_delete(nodePtr np) {
 
 void on_popup_prop_selected(gpointer callback_data, guint callback_action, GtkWidget *widget) {
 	feedPtr		fp = (feedPtr)callback_data;
-	
+
 	g_assert(NULL != fp);
 	if(NULL != fp) {
 		if(FST_FEED == feed_get_type(fp)) {
+			/* loading/unloading the feed because the cache 
+			   properties might be changed */
+			feedlist_load_feed(fp);
 			ui_feed_propdialog_new(GTK_WINDOW(mainwindow),fp);
+			feedlist_unload_feed(fp);
 			return;
 		} 
 		if(FST_VFOLDER == feed_get_type(fp)) {
