@@ -75,6 +75,19 @@ static gint timeCompFunc(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gp
 		return 0;
 }
 
+void ui_itemlist_reset_tree_store() {
+	GtkTreeModel	*model;
+	
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(lookup_widget(mainwindow, "Itemlist")));
+	ui_itemlist_clear();
+	gtk_tree_view_set_model(GTK_TREE_VIEW(lookup_widget(mainwindow, "Itemlist")), NULL);
+
+	displayed_item = NULL;
+	g_object_unref(model);
+	gtk_tree_view_set_model(GTK_TREE_VIEW(lookup_widget(mainwindow, "Itemlist")), GTK_TREE_MODEL(ui_itemlist_get_tree_store()));
+	
+}
+
 GtkTreeStore * ui_itemlist_get_tree_store(void) {
 	GtkTreeModel	*model;
 	GtkTreeStore	*itemstore;
@@ -93,7 +106,7 @@ GtkTreeStore * ui_itemlist_get_tree_store(void) {
 		                               G_TYPE_ULONG,
 		                               G_TYPE_STRING, 
 		                               G_TYPE_STRING,
-					       G_TYPE_POINTER,
+									   G_TYPE_POINTER,
 		                               GDK_TYPE_PIXBUF,
 		                               G_TYPE_ULONG,
 		                               GDK_TYPE_PIXBUF);
@@ -320,7 +333,6 @@ void ui_itemlist_init(GtkWidget *itemlist) {
 	gtk_tree_view_column_set_sort_column_id(column, IS_TIME);
 	g_object_set(column, "resizable", TRUE, NULL);
 	
-	
 	renderer = gtk_cell_renderer_pixbuf_new();
 	column = gtk_tree_view_column_new_with_attributes("", renderer, "pixbuf", IS_ICON2, NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(itemlist), column);
@@ -331,6 +343,9 @@ void ui_itemlist_init(GtkWidget *itemlist) {
 	gtk_tree_view_column_set_sort_column_id(column, IS_LABEL);
 
 	g_object_set(column, "resizable", TRUE, NULL);
+#if GTK_CHECK_VERSION(2,6,0)
+	g_object_set(renderer, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
+#endif
 
 	/* And connect signals */	
 	g_signal_connect(G_OBJECT(GTK_TREE_VIEW(itemlist)), "key-press-event", G_CALLBACK(ui_itemlist_key_press_cb), NULL);
@@ -482,10 +497,10 @@ void ui_itemlist_add_item(itemPtr ip, gboolean merge) {
 			g_hash_table_insert(iterhash, (gpointer)ip, (gpointer)iter);
 		}	
 		gtk_tree_store_set(itemstore, iter,
-		                	      IS_NR, ip->nr,
-					      IS_FEED, ip->fp,
-		                	      IS_TIME, item_get_time(ip),
-		                	      -1);
+						   IS_NR, ip->nr,
+						   IS_FEED, ip->fp,
+						   IS_TIME, item_get_time(ip),
+						   -1);
 		ui_itemlist_update_item(ip);
 	}
 }
@@ -515,7 +530,7 @@ void on_popup_launchitem_selected(void) {
 	itemPtr		ip;
 
 	if(NULL != (ip = ui_itemlist_get_selected()))
-		ui_htmlview_launch_URL(ui_tabs_get_active_htmlview(), (gchar *)item_get_source(ip), UI_HTMLVIEW_LAUNCH_EXTERNAL);
+		ui_htmlview_launch_URL(ui_tabs_get_active_htmlview(), (gchar *)item_get_source(ip), UI_HTMLVIEW_LAUNCH_DEFAULT);
 	else
 		ui_mainwindow_set_status_bar(_("No item has been selected"));
 }
@@ -570,22 +585,24 @@ void on_remove_items_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
 void on_remove_item_activate(GtkMenuItem *menuitem, gpointer user_data) {
 	GtkTreeSelection	*selection;
-	nodePtr			np;
 	itemPtr			ip;
 	
-	np = ui_feedlist_get_selected();
-	if((NULL != np) && (FST_FEED == np->type)) {
-		if(NULL != (ip = ui_itemlist_get_selected())) {
-			/* must unselect the item to avoid deferred removal */
+	if(NULL != (ip = ui_itemlist_get_selected())) {
+		/* 1. order is important, first remove then unselect! */
+		itemlist_remove_item(ip);
+
+		/* 2. deferred removal forces us to unselect the item 
+		      One way to do it is to move forward the cursor. */
+		on_treeview_move("Itemlist", 1);
+
+		/* 3. But 2. might not be enough, e.g. if ip was the
+		      last item and is still selected (not removed) */
+		if(ui_itemlist_get_selected() == ip) {
 			selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(lookup_widget(mainwindow, "Itemlist")));
 			gtk_tree_selection_unselect_all(selection);
-			itemlist_remove_item(ip);
-			ui_htmlview_clear(ui_mainwindow_get_active_htmlview());
-		} else {
-			ui_mainwindow_set_status_bar(_("No item has been selected"));
 		}
 	} else {
-		ui_show_error_box(_("You must select a feed to delete its items!"));
+		ui_mainwindow_set_status_bar(_("No item has been selected"));
 	}
 }
 
@@ -791,6 +808,21 @@ void on_toggle_condensed_view_activate(GtkMenuItem *menuitem, gpointer user_data
 	}
 }
 
+/* Callback for the toolbar to switch between two and three pane mode */
+void on_toggle_condensed_view_clicked(GtkButton *button, gpointer user_data) {
+	nodePtr		np;
+
+	itemlist_set_two_pane_mode(!ui_itemlist_get_two_pane_mode());
+
+	if(NULL != (np = ui_feedlist_get_selected())) {
+		/* grab necessary to force HTML widget update (display must
+		   change from feed description to list of items and vica 
+		   versa */
+		gtk_widget_grab_focus(lookup_widget(mainwindow, "feedlist"));
+		itemlist_load(np);
+	}
+}
+
 void on_popup_copy_URL_clipboard(void) {
 	itemPtr         ip;
 
