@@ -39,7 +39,6 @@
 #include "ui_htmlview.h"
 #include "ui_itemlist.h"
 #include "ui_session.h"
-#include "ui_queue.h"
 #include "update.h"
 
 #if GTK_CHECK_VERSION(2,4,0)
@@ -95,7 +94,7 @@ static void on_treeview_set_first(char* treename) {
 }
 
 /* Move treeview cursor up and down. */
-static void on_treeview_move(char* treename, gint step) {
+void on_treeview_move(char* treename, gint step) {
 	GtkTreeView	*treeview;
 	gboolean	ret;
 
@@ -119,29 +118,70 @@ gboolean on_mainwindow_key_press_event(GtkWidget *widget, GdkEventKey *event, gp
 	GtkWidget	*focusw;
 
 	if(event->type == GDK_KEY_PRESS) {
+		default_modifiers = gtk_accelerator_get_default_mod_mask();
+
 		/* handle headline skimming hotkey */
-		if(event->keyval == GDK_space) {
-			switch(getNumericConfValue(BROWSE_KEY_SETTING)) {
-				case 0:
-					modifier_matches = ((event->state & GDK_CONTROL_MASK) == GDK_CONTROL_MASK);
+		switch(event->keyval) {
+			case GDK_space:
+				switch(getNumericConfValue(BROWSE_KEY_SETTING)) {
+					case 0:
+						modifier_matches = ((event->state & GDK_CONTROL_MASK) == GDK_CONTROL_MASK);
+						break;
+					default:
+					case 1:
+						modifier_matches = ((event->state & default_modifiers) == 0);
+						if(!strcmp(htmlviewInfo->name, "Mozilla")) /* Hack to make space handled in the module */
+							return FALSE;
+						break;
+					case 2:
+						modifier_matches = ((event->state & GDK_MOD1_MASK) == GDK_MOD1_MASK);
+						break;
+				}
+				
+				if(modifier_matches) {
+					/* Note that this code is duplicated in mozilla/mozilla.cpp! */
+					if(ui_htmlview_scroll() == FALSE)
+						on_next_unread_item_activate(NULL, NULL);
+					return TRUE;
+				}
+				break;
+		}
+
+		/* menu hotkeys (duplicated so they work with hidden menu */
+		if(GDK_CONTROL_MASK == (event->state & default_modifiers)) {
+			switch(event->keyval) {
+				case GDK_KP_Add:
+					on_popup_zoomin_selected(NULL, 0, NULL);
+					return TRUE;
 					break;
-				default:
-				case 1:
-					default_modifiers = gtk_accelerator_get_default_mod_mask();
-					modifier_matches = ((event->state & default_modifiers) == 0);
-					if(!strcmp(htmlviewInfo->name, "Mozilla")) /* Hack to make space handled in the module */
-						return FALSE;
+				case GDK_KP_Subtract:
+					on_popup_zoomout_selected(NULL, 0, NULL);
+					return TRUE;
 					break;
-				case 2:
-					modifier_matches = ((event->state & GDK_MOD1_MASK) == GDK_MOD1_MASK);
-					break;
-			}
-			
-			if(modifier_matches) {
-				/* Note that this code is duplicated in mozilla/mozilla.cpp! */
-				if(ui_htmlview_scroll() == FALSE)
+				case GDK_n:
 					on_next_unread_item_activate(NULL, NULL);
-				return TRUE;
+					return TRUE;
+					break;
+				case GDK_r:
+					on_popup_allunread_selected();
+					return TRUE;
+					break;
+				case GDK_t:
+					on_toggle_item_flag(NULL, NULL);
+					return TRUE;
+					break;
+				case GDK_u:
+					on_toggle_unread_status(NULL, NULL);
+					return TRUE;
+					break;
+				case GDK_a:
+					on_refreshbtn_clicked(NULL, NULL);
+					return TRUE;
+					break;
+				case GDK_f:
+					on_searchbtn_clicked(NULL, NULL);
+					return TRUE;
+					break;
 			}
 		}
 
@@ -158,29 +198,36 @@ gboolean on_mainwindow_key_press_event(GtkWidget *widget, GdkEventKey *event, gp
 		/* somehow we don't need to check for GtkHTML2... */
 
 		/* check for treeview navigation */
-		switch (event->keyval) {
-			case GDK_n: 
-				on_next_unread_item_activate(NULL, NULL);
-				return TRUE;
-				break;
-			case GDK_f:
-				on_treeview_next("Itemlist");
-				return TRUE;
-				break;
-			case GDK_b:
-				on_treeview_prev("Itemlist");
-				return TRUE;
-				break;
-			case GDK_u:
-				on_treeview_prev("feedlist");
-				on_treeview_set_first("Itemlist");
-				return TRUE;
-				break;
-			case GDK_d:
-				on_treeview_next("feedlist");
-				on_treeview_set_first("Itemlist");
-				return TRUE;
-				break;
+		if(0 == (event->state & default_modifiers)) {
+			switch(event->keyval) {
+				case GDK_KP_Delete:
+				case GDK_Delete:
+					on_remove_item_activate(NULL, NULL);
+					return TRUE;
+					break;
+				case GDK_n: 
+					on_next_unread_item_activate(NULL, NULL);
+					return TRUE;
+					break;
+				case GDK_f:
+					on_treeview_next("Itemlist");
+					return TRUE;
+					break;
+				case GDK_b:
+					on_treeview_prev("Itemlist");
+					return TRUE;
+					break;
+				case GDK_u:
+					on_treeview_prev("feedlist");
+					on_treeview_set_first("Itemlist");
+					return TRUE;
+					break;
+				case GDK_d:
+					on_treeview_next("feedlist");
+					on_treeview_set_first("Itemlist");
+					return TRUE;
+					break;
+			}
 		}
 	}
 	
@@ -255,15 +302,20 @@ GtkWidget* ui_mainwindow_new(void) {
 	GtkWidget *toolbar = lookup_widget(window, "toolbar");
 	GtkTooltips *tooltips = gtk_tooltips_new();
 	gchar *toolbar_style = getStringConfValue("/desktop/gnome/interface/toolbar_style");
-
+	
+	gtk_widget_set_name(window, "lifereaMainwindow");
+	gtk_widget_set_name(lookup_widget(window, "feedlist"), "feedlist");
+	gtk_widget_set_name(lookup_widget(window, "Itemlist"), "itemlist");
+	
 	ui_mainwindow_set_toolbar_style(GTK_WINDOW(window), toolbar_style);
 	g_free(toolbar_style);
 
 	TOOLBAR_ADD(toolbar,  _("New Feed"), GTK_STOCK_ADD, tooltips,  _("Add a new subscription."), on_newbtn_clicked);
 	TOOLBAR_ADD(toolbar,  _("Next Unread"), GTK_STOCK_GO_FORWARD, tooltips,  _("Jumps to the next unread item. If necessary selects the next feed with unread items."), on_nextbtn_clicked);
-	TOOLBAR_ADD(toolbar,  _("Mark As Read"), GTK_STOCK_APPLY, tooltips,  _("Mark all items of the selected subscription or of all subscriptions of the selected folder as read."), on_popup_allunread_selected);
+	TOOLBAR_ADD(toolbar,  _("Mark As Read"), GTK_STOCK_APPLY, tooltips,  _("Marks all items of the selected subscription or of all subscriptions of the selected folder as read."), on_popup_allunread_selected);
 	TOOLBAR_ADD(toolbar,  _("Update All"), GTK_STOCK_REFRESH, tooltips,  _("Updates all subscriptions. This does not update OCS directories."), on_refreshbtn_clicked);
 	TOOLBAR_ADD(toolbar,  _("Search"), GTK_STOCK_FIND, tooltips,  _("Search all feeds."), on_searchbtn_clicked);
+	TOOLBAR_ADD(toolbar,  _("Viewing Mode"), GTK_STOCK_JUSTIFY_FILL, tooltips,  _("Switches between 2 and 3 pane mode."), on_toggle_condensed_view_clicked);
 	TOOLBAR_ADD(toolbar,  _("Preferences"), GTK_STOCK_PREFERENCES, tooltips,  _("Edit preferences."), on_prefbtn_clicked);
 
 	g_signal_connect ((gpointer) lookup_widget(window, "itemtabs"), "key_press_event",
@@ -299,37 +351,24 @@ void ui_mainwindow_finish(GtkWidget *window) {
 	
 	/* create welcome text */
 	ui_htmlview_start_output(&buffer, NULL, FALSE);
-	/*addToHTMLBuffer(&buffer, _("<div style=\"background-color:#f7f0a3;padding:5px;border:solid 1px black\">"
-	                           "When Liferea starts for the first time it loads a localized default "
-				   "feed list. There are already default lists for English, French, German "
-				   "and Spanish. If you think you know a good set of default feeds for your "
-				   "language please post them (maybe as OPML) on the <a href=\"mailto:liferea-devel@lists.sourceforge.net\">mailing list</a> "
-				   "and it will be included in the next release!</div>"));*/
+	addToHTMLBuffer(&buffer, "<div style=\"background-color:#eee;padding:5px;border:solid 1px #aaa\">"
+				 "<table border=0 cellpadding=5px><tr><td>"
+				 // add application icon
+				 "<img src=\""
+				 PACKAGE_DATA_DIR G_DIR_SEPARATOR_S PACKAGE G_DIR_SEPARATOR_S "pixmaps" G_DIR_SEPARATOR_S
+				 "liferea.png\">"
+				 "</td><td><h3>");
+	addToHTMLBuffer(&buffer, _("Liferea - Linux Feed Reader"));
+	addToHTMLBuffer(&buffer, "</td></tr><tr><td colspan=2>");
+	addToHTMLBuffer(&buffer, _("<p>Welcome to <b>Liferea</b>, a desktop news aggregator for online news "
+				   "feeds.</p>"
+				   "<p>The left pane contains the list of your subscriptions. To add a "
+				   "subscription select <tt>Feeds -&gt; New Subscription</tt>. To browse the headlines "
+				   "of a feed select it in the feed list and the headlines will be loaded "
+				   "into the right pane.</p>"));
+	addToHTMLBuffer(&buffer, "</tr></table>"
+				 "</div>");
 				   
-	addToHTMLBuffer(&buffer, _("<h2>Welcome to Liferea</h2>"
-	                           "<p>The left pane contains the feed list where you can add new subscriptions "
-	                           "and select subscriptions to read their headlines. The right side either "
-	                           "displays a list of the headlines of the selected subscription and a "
-	                           "pane to view the selected headline or all headlines at once if condensed "
-	                           "mode is selected.</p>"
-	                           "<h3>Basic Actions</h3>"
-	                           "<ul>"
-	                           "<li><p><b>Add Subscription</b> - Creates a new subscription in the selected "
-	                           "folder. To create a new subscription enter the feed URL or if you don't "
-	                           "know it the URL of the website which provides the feed.</p></li>"
-	                           "<li><p><b>Update Subscription</b> - This will update the subscription you selected. "
-	                           "You may want to do this if you want to immediatly check a subscription for "
-	                           "updates. Usually it is adequate to rely on the auto updating according to the "
-	                           "update interval of the subscription.</p></li>"
-	                           "<li><p><b>Update All</b> - This will update all your subscriptions at once. "
-	                           "Again usually it is adequate to rely on the auto updating.</li>"
-	                           "<li><p><b>Edit Subscription Properties</b> - Sometimes you might want to "
-	                           "change the update interval, title, authentication or caching properties "
-	                           "of a subscription.</p></li>"
-	                           "</ul>"
-	                           "<p>To learn more about Liferea you should read the documentation "
-	                           "provided in the help feed or in the <a href=\"http://liferea.sourceforge.net/faq.htm\">FAQ</a> available at the "
-	                           "<a href=\"http://liferea.sf.net\">project homepage</a>.</p>"));
 	ui_htmlview_finish_output(&buffer);
 	ui_htmlview_write(ui_mainwindow_get_active_htmlview(), buffer, NULL);
 	g_free(buffer);
@@ -396,6 +435,7 @@ void on_onlinebtn_clicked(GtkButton *button, gpointer user_data) {
 	
 	download_set_online(!download_is_online());
 	ui_mainwindow_update_onlinebtn();
+	ui_tray_update();
 
 	GTK_CHECK_MENU_ITEM(lookup_widget(mainwindow, "work_offline"))->active = !download_is_online();
 }
@@ -404,19 +444,7 @@ void on_work_offline_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
 	download_set_online(!GTK_CHECK_MENU_ITEM(menuitem)->active);
 	ui_mainwindow_update_onlinebtn();
-}
-
-static int ui_mainwindow_set_status_idle(gpointer data) {
-	gchar		*statustext = (gchar *)data;
-	GtkWidget	*statusbar;
-	
-	g_assert(NULL != mainwindow);
-	statusbar = lookup_widget(mainwindow, "statusbar");
-	g_assert(NULL != statusbar);
-
-	gtk_label_set_text(GTK_LABEL(GTK_STATUSBAR(statusbar)->label), statustext);	
-	g_free(statustext);
-	return 0;
+	ui_tray_update();
 }
 
 /* Set the main window status bar to the text given as 
@@ -424,6 +452,7 @@ static int ui_mainwindow_set_status_idle(gpointer data) {
 void ui_mainwindow_set_status_bar(const char *format, ...) {
 	va_list		args;
 	char 		*str = NULL;
+	GtkWidget	*statusbar;
 	
 	g_return_if_fail(format != NULL);
 
@@ -431,7 +460,12 @@ void ui_mainwindow_set_status_bar(const char *format, ...) {
 	str = g_strdup_vprintf(format, args);
 	va_end(args);
 
-	ui_queue_add(ui_mainwindow_set_status_idle, (gpointer)str); 
+	g_assert(NULL != mainwindow);
+	statusbar = lookup_widget(mainwindow, "statusbar");
+	g_assert(NULL != statusbar);
+
+	gtk_label_set_text(GTK_LABEL(GTK_STATUSBAR(statusbar)->label), str);
+	g_free(str);
 }
 
 void ui_mainwindow_save_position(void) {
@@ -540,10 +574,8 @@ void ui_mainwindow_toggle_visibility(GtkMenuItem *menuitem, gpointer data) {
 gboolean on_mainwindow_window_state_event(GtkWidget *widget, GdkEvent *event, gpointer user_data) {
 	if((event->type) == (GDK_WINDOW_STATE)) {
 		GdkWindowState changed = ((GdkEventWindowState*)event)->changed_mask, state = ((GdkEventWindowState*)event)->new_window_state;
-	
-		//if(!GTK_WIDGET_VISIBLE(mainwindow))
-		//return FALSE;
-		if (changed == GDK_WINDOW_STATE_MAXIMIZED) {
+		
+		if (changed == GDK_WINDOW_STATE_MAXIMIZED && !(state & GDK_WINDOW_STATE_WITHDRAWN)) {
 			if(state & GDK_WINDOW_STATE_MAXIMIZED)
 				setBooleanConfValue(LAST_WINDOW_MAXIMIZED, TRUE);
 			else
@@ -604,13 +636,13 @@ static void ui_choose_file_cb_canceled(GtkButton *button, gpointer user_data) {
 }
 #endif
 
-static void ui_choose_file_or_dir(gchar *title, GtkWindow *parent, gchar *buttonName, gboolean saving, gboolean directory, fileChoosenCallback callback, const gchar *currentFilename, const gchar *filename, gpointer user_data) {
+static void ui_choose_file_or_dir(gchar *title, GtkWindow *parent, gchar *buttonName, gboolean saving, gboolean directory, fileChoosenCallback callback, const gchar *currentPath, const gchar *defaultFilename, gpointer user_data) {
 	GtkWidget			*dialog;
 	struct file_chooser_tuple	*tuple;
 	GtkWidget			*button;
 
-	g_assert(TRUE != (saving & directory));
-
+	g_assert(!(saving && directory));
+	g_assert(!(defaultFilename && !saving));
 #if GTK_CHECK_VERSION(2,4,0)
 	dialog = gtk_file_chooser_dialog_new(title,
 	                                     parent,
@@ -619,8 +651,6 @@ static void ui_choose_file_or_dir(gchar *title, GtkWindow *parent, gchar *button
 	                                     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 	                                     NULL);
 	gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
-	if(NULL != currentFilename)
-		gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(dialog), currentFilename);
 	tuple = g_new0(struct file_chooser_tuple, 1);
 	tuple->dialog = dialog;
 	tuple->func = callback;
@@ -632,9 +662,16 @@ static void ui_choose_file_or_dir(gchar *title, GtkWindow *parent, gchar *button
 	
 	g_signal_connect(G_OBJECT(dialog), "response",
 	                 G_CALLBACK(ui_choose_file_save_cb), tuple);
-	if(filename != NULL && g_file_test(filename, G_FILE_TEST_EXISTS))
-		gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(dialog), filename);
-	gtk_widget_show_all(dialog);
+
+	if(currentPath && g_file_test(currentPath, G_FILE_TEST_EXISTS)) {
+		if (directory)
+			gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog), currentPath);
+		else
+			gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(dialog), currentPath);
+	}
+	if(defaultFilename) /* saving */
+			gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(dialog), defaultFilename);
+		gtk_widget_show_all(dialog);
 #else
 	dialog = gtk_file_selection_new(title);
 	gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(parent));
@@ -645,11 +682,19 @@ static void ui_choose_file_or_dir(gchar *title, GtkWindow *parent, gchar *button
 	tuple->func = callback;
 	tuple->user_data = user_data;
 
-	if(filename != NULL)
-		gtk_file_selection_set_filename(GTK_FILE_SELECTION(dialog), filename);
-		
-	if(TRUE == directory)
+	if(defaultFilename) 
+		gtk_file_selection_set_filename(GTK_FILE_SELECTION(dialog), defaultFilename);
+	else if(currentPath) 
+		gtk_file_selection_set_filename(GTK_FILE_SELECTION(dialog), currentPath);
+
+	if(directory) {
 		gtk_file_selection_hide_fileop_buttons(GTK_FILE_SELECTION(dialog));
+		/* hiding the widget seems to be the only way to get
+		   a directory only selection dialog, copied from the
+		   GIMP code */
+		gtk_widget_hide(GTK_FILE_SELECTION(dialog)->file_list);
+		gtk_widget_hide(GTK_FILE_SELECTION(dialog)->file_list->parent);
+	}
 		
 	g_signal_connect(GTK_FILE_SELECTION(dialog)->ok_button,
 	                 "clicked",
@@ -661,7 +706,7 @@ static void ui_choose_file_or_dir(gchar *title, GtkWindow *parent, gchar *button
 	                 G_CALLBACK(ui_choose_file_cb_canceled),
 	                 tuple);
 	
-	gtk_widget_show_all(dialog);
+	gtk_widget_show(dialog);
 #endif
 }
 
@@ -670,7 +715,14 @@ void ui_choose_file(gchar *title, GtkWindow *parent, gchar *buttonName, gboolean
 	ui_choose_file_or_dir(title, parent, buttonName, saving, FALSE, callback, currentFilename, filename, user_data);
 }
 
-void ui_choose_directory(gchar *title, GtkWindow *parent, gchar *buttonName, fileChoosenCallback callback, const gchar *currentFilename, const gchar *filename, gpointer user_data) {
+void ui_choose_directory(gchar *title, GtkWindow *parent, gchar *buttonName, fileChoosenCallback callback, const gchar *dirname, gpointer user_data) {
+	gchar	*tmp;
+		
+	if('/' != *(dirname + strlen(dirname) - 1))
+		tmp = g_strdup_printf("%s/", dirname);
+	else
+		tmp = g_strdup(dirname);
 
-	ui_choose_file_or_dir(title, parent, buttonName, FALSE, TRUE, callback, currentFilename, filename, user_data);
+	ui_choose_file_or_dir(title, parent, buttonName, FALSE, TRUE, callback, tmp, NULL, user_data);
+	g_free(tmp);
 }
