@@ -50,6 +50,7 @@ enum fts_columns {
 };
 
 extern GSList *availableBrowserModules;
+extern nodePtr displayed_node;
 
 static GtkWidget *prefdialog = NULL;
 
@@ -315,6 +316,7 @@ void on_prefbtn_clicked(GtkButton *button, gpointer user_data) {
 
 		g_signal_connect(GTK_OBJECT(lookup_widget(prefdialog, "updateAllFavicons")), "clicked", G_CALLBACK(on_updateallfavicons_clicked), NULL);	
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(prefdialog, "folderdisplaybtn")), (0 == getNumericConfValue(FOLDER_DISPLAY_MODE)?FALSE:TRUE));
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(prefdialog, "hidereadbtn")), (0 == getBooleanConfValue(FOLDER_DISPLAY_HIDE_READ)?FALSE:TRUE));
 
 		/* ================== panel 3 "headlines" ==================== */
 
@@ -338,7 +340,7 @@ void on_prefbtn_clicked(GtkButton *button, gpointer user_data) {
 		/* Time format */
 		tmp = getNumericConfValue(TIME_FORMAT_MODE);
 		if((tmp > 3) || (tmp < 1)) 
-			tmp = 1;	/* correct configuration if necessary */
+			tmp = 2;	/* correct configuration if necessary (default is time+date) */
 
 		entry = lookup_widget(prefdialog, "timeformatentry");
 		gtk_entry_set_text(GTK_ENTRY(entry), getStringConfValue(TIME_FORMAT));
@@ -495,6 +497,7 @@ void on_prefbtn_clicked(GtkButton *button, gpointer user_data) {
 			edtool++;
 			i++;
 		}		
+        gtk_menu_set_active(GTK_MENU(menu), getNumericConfValue(ENCLOSURE_DOWNLOAD_TOOL));
 		gtk_option_menu_set_menu(GTK_OPTION_MENU(lookup_widget(prefdialog, "enc_download_tool_option_btn")), menu);
 
 		/* set enclosure download path entry */	
@@ -513,7 +516,7 @@ void on_prefbtn_clicked(GtkButton *button, gpointer user_data) {
 					   -1);
 			list = g_slist_next(list);
 		}
-
+		
 		widget = lookup_widget(prefdialog, "enc_actions_view");
 		gtk_tree_view_set_model(GTK_TREE_VIEW(widget), GTK_TREE_MODEL(treestore));
 
@@ -539,6 +542,13 @@ void on_folderdisplaybtn_toggled(GtkToggleButton *togglebutton, gpointer user_da
 	setNumericConfValue(FOLDER_DISPLAY_MODE, (TRUE == enabled)?1:0);
 }
 
+void on_folderhidereadbtn_toggled(GtkToggleButton *togglebutton, gpointer user_data) {
+
+	gboolean enabled = gtk_toggle_button_get_active(togglebutton);
+	setBooleanConfValue(FOLDER_DISPLAY_HIDE_READ, enabled);
+	itemlist_load(displayed_node);
+}
+
 void on_trayiconoptionbtn_clicked(GtkButton *button, gpointer user_data) {
 
 	gboolean enabled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
@@ -771,7 +781,6 @@ static void on_save_download_finished(const gchar *filename, gpointer user_data)
 
 void on_save_download_select_btn_clicked(GtkButton *button, gpointer user_data) {
 	
-	ui_choose_directory(_("Choose download directory"), GTK_WINDOW(prefdialog), GTK_STOCK_OPEN, on_save_download_finished, "", "", prefdialog);
+	ui_choose_directory(_("Choose download directory"), GTK_WINDOW(prefdialog), GTK_STOCK_OPEN, on_save_download_finished, 
+						 gtk_editable_get_chars(GTK_EDITABLE(lookup_widget(prefdialog, "save_download_entry")), 0, -1), prefdialog);
 }
-
-
