@@ -34,6 +34,7 @@
 #include "ui_tray.h"
 #include "ui_popup.h"
 #include "ui_mainwindow.h"
+#include "update.h"
 
 #define NO_NEW_ITEMS	0
 #define NEW_ITEMS	1
@@ -47,6 +48,7 @@ static EggTrayIcon 	*tray_icon =  NULL;
 static GtkTooltips	*tray_icon_tips = NULL;
 static GtkWidget	*image = NULL;		/* the image in the notification area */
 static int trayCount = 0;
+static GdkPixbuf *currentIcon = NULL;
 
 static void installTrayIcon(void);
 
@@ -59,9 +61,7 @@ void ui_tray_tooltip_set(gchar *message) {
 
 	if(NULL != data) {
 		/* FIXME: Is this necessary? Gtk 2.2.4 frees these strings
-		   inside of set_tip, if needed. Also, shouldn't they be set
-		   to NULL after freeing so that GTK does not double-free
-		   them? */
+		   inside of set_tip, if needed. */
 		g_free(data->tip_text);
 		g_free(data->tip_private);
 		data->tip_text = NULL;
@@ -76,7 +76,12 @@ void ui_tray_tooltip_set(gchar *message) {
 static void ui_tray_icon_set(GdkPixbuf *icon) {
 
 	g_assert(tray_icon);
-
+	
+	/* Skip loading icon if already displayed. */
+	if (icon == currentIcon)
+		return;
+	currentIcon = icon;
+	
 	if(NULL != image)
 		gtk_widget_destroy(image);
 
@@ -96,15 +101,22 @@ void ui_tray_update(void) {
 	unreadItems = feedlist_get_unread_item_count();
 		
 	if(newItems != 0) {
-		ui_tray_icon_set(icons[ICON_AVAILABLE]); 
-		tmp = g_strdup_printf(ngettext("%d new item", "%d new items", newItems), newItems);
-		msg = g_strdup_printf(ngettext("%s\n%d unread item", "%s\n%d unread items", unreadItems), tmp, unreadItems);
+		if(download_is_online()) ui_tray_icon_set(icons[ICON_AVAILABLE]);
+		else ui_tray_icon_set(icons[ICON_AVAILABLE_OFFLINE]);
+		msg = g_strdup_printf(ngettext("%d new item", "%d new items", newItems), newItems);
 	} else {
-		ui_tray_icon_set(icons[ICON_EMPTY]);
-		tmp = g_strdup(_("No new items"));
-		msg = g_strdup_printf(ngettext("%s\n%d unread item", "%s\n%d unread items", unreadItems), tmp, unreadItems);
+		if(download_is_online()) ui_tray_icon_set(icons[ICON_EMPTY]);
+		else ui_tray_icon_set(icons[ICON_EMPTY_OFFLINE]);
+		msg = g_strdup(_("No new items"));
 	}
-	ui_tray_tooltip_set(msg);
+
+	if(unreadItems != 0) {
+		tmp = g_strdup_printf(ngettext("%s\n%d unread item", "%s\n%d unread items", unreadItems), msg, unreadItems);
+	} else {
+		tmp = g_strdup_printf(_("%s\nNo unread items"), msg);
+	}
+
+	ui_tray_tooltip_set(tmp);
 	g_free(tmp);
 	g_free(msg);
 }
