@@ -1,8 +1,8 @@
 /**
  * @file update.c feed update request processing
  *
- * Copyright (C) 2003, 2004 Lars Lindner <lars.lindner@gmx.net>
- * Copyright (C) 2004 Nathan J. Conrad <t98502@users.sourceforge.net>
+ * Copyright (C) 2003-2005 Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2004-2005 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,6 @@
 #include "debug.h"
 #include "update.h"
 #include "conf.h"
-#include "ui_queue.h"
 #include "ui_mainwindow.h"
 #include "net/downloadlib.h"
 
@@ -109,7 +108,7 @@ void download_process(struct request *request) {
 	FILE	*f;
 	size_t	len;
 	int	status;
-	gchar	*tmp, *errorOutput;
+	gchar	*cmd, *tmp, *errorOutput;
 
 	request->data = NULL;
 	request->size = 0;
@@ -166,8 +165,18 @@ void download_process(struct request *request) {
 
 	/* And execute the postfilter */
 	if(request->data != NULL && request->filtercmd != NULL) {
+		/* we allow two types of filters: XSLT stylesheets and arbitrary commands */
+		if((strlen(request->filtercmd) > 4) &&
+		   (0 == strcmp(".xsl", request->filtercmd + strlen(request->filtercmd) - 4))) {
+			/* in case of XSLT we call xsltproc */
+			cmd = g_strdup_printf("xsltproc %s -", request->filtercmd);
+		} else {
+			/* otherwise we just keep the given command */
+			cmd = g_strdup(request->filtercmd);
+		}
+
 		errorOutput = NULL;
-		tmp = filter(request->filtercmd, request->data, &errorOutput, &len);
+		tmp = filter(cmd, request->data, &errorOutput, &len);
 		g_free(request->filterErrors);
 		request->filterErrors = errorOutput;
 		if(tmp != NULL) {
@@ -227,7 +236,11 @@ void download_init(void) {
 		g_thread_create(download_thread_main, (void *)(i == 0), FALSE, NULL);
 
 	/* setup the processing of feed update results */
-	ui_timeout_add(100, download_dequeuer, NULL);
+	g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE,
+	                   100, 
+			   download_dequeuer, 
+			   NULL,
+			   NULL);
 }
 
 static void *download_thread_main(void *data) {
@@ -251,11 +264,12 @@ static void *download_thread_main(void *data) {
 			request = g_async_queue_pop(requests_high_prio);
 		} else {
 			request = g_async_queue_try_pop(requests_high_prio);
-			if(NULL == request) request = g_async_queue_pop(requests_normal_prio);
+			if(NULL == request) 
+				request = g_async_queue_pop(requests_normal_prio);
 		}
 		g_assert(NULL != request);
 		debug1(DEBUG_UPDATE, "processing received request (%s)", request->source);
-		if (request->callback == NULL) {
+		if(request->callback == NULL) {
 			debug1(DEBUG_UPDATE, "freeing cancelled request (%s)", request->source);
 			download_request_free(request);
 		} else {
@@ -300,15 +314,7 @@ static gboolean download_dequeuer(gpointer user_data) {
 		if(request->callback == NULL) {
 			debug1(DEBUG_UPDATE, "freeing cancelled request (%s)", request->source);
 		} else {
-			/* When processing a request that is assigned to a
-			   certain feed the callback depends on the existence 
-			   of the feed. To prevent any user interactions
-			   that could delete the feed we lock the GUI */
-			ui_lock();
-			
 			(request->callback)(request);
-			
-			ui_unlock();
 		}
 		download_request_free(request);
 	}
